import type { CascaderProps } from 'antd';
import type { IContainer, MixinElement } from '../interface';
/**
 * Fires onDropdownVisibleChange for Cascader, and open drowdown
 * @example
 * const fn = jest.fn();
 * const { container } = render(<Cascader onDropdownVisibleChange={fn} />);
 * cascader.fireOpen(container);
 * expect(fn).toBeCalledTimes(1);
 */
export declare function fireOpen(container: IContainer): void;
/**
 * Fires onChange for Cascader
 * @param indexes each panel's index
 * @example
 * const fn = jest.fn();
 * const { container } = render(
 *     <Cascader onChange={fn} getPopupContainer={(node) => node.parentNode} options={options} />
 * );
 * cascader.fireOpen(container);
 * cascader.fireChange(container, 0, 0, 0);
 * expect(fn).toBeCalled();
 */
export declare function fireChange(container: IContainer, ...indexes: number[]): void;
/**
 * Fires onChange for Cascader by click or hover
 * @param type as same as Cascader's expandTrigger
 * @param indexes each panel's index
 * @example
 * const fn = jest.fn();
 * const { container } = render(
 *     <Cascader onChange={fn} getPopupContainer={(node) => node.parentNode} options={options} />
 * );
 * cascader.fireOpen(container);
 * cascader.fireChange(container, 0, 0, 0);
 * expect(fn).toBeCalled();
 */
export declare function fireChange(container: IContainer, type: CascaderProps['expandTrigger'], ...indexes: number[]): void;
/**
 * Fires onSearch for Cascader
 * @example
 * const fn = jest.fn();
 * const { container } = render(
 *     <Cascader
 *         showSearch={{
 *             filter: (inputValue, path) =>
 *                 path.some(
 *                     (option) => (option.label as string).toLowerCase().indexOf(inputValue.toLowerCase()) > -1
 *                 ),
 *         }}
 *         onSearch={fn}
 *     />
 * );
 * cascader.fireSearch(container, 'test');
 * expect(fn).toBeCalled();
 */
export declare function fireSearch(container: IContainer, value: string): void;
/**
 * Fires onClear for Cascader
 * @notice clear button **ONLY** accessible for non-empty value
 * @example
 * const fn = jest.fn();
 * const { container } = render(
 *     <Cascader onClear={fn} options={options} allowClear defaultValue={['1', '1-1', '1-1-1']} />
 * );
 * cascader.fireClear(container);
 * expect(fn).toBeCalled();
 */
export declare function fireClear(container: IContainer): void;
/**
 * Returns the `index` element of Cascader's container
 * @param index the order of Cascader's container, default is `0`
 * @example
 * const { container, getByTestId } = render(
 *     <div>
 *         <Cascader data-testid="cascader1" />
 *         <Cascader data-testid="cascader2" />
 *     </div>
 * );
 * expect(cascader.query(container)).toBe(getByTestId('cascader1'));
 * expect(cascader.query(container, 1)).toBe(getByTestId('cascader2'));
 */
export declare function query(container: IContainer, index?: number): QueryReturnElement;
/**
 * Returns the `index` element of Cascader's Select
 * @param index the order of Cascader's Select, default is `0`
 * @example
 * const fn = jest.fn();
 * const { container } = render(
 *     <div>
 *         <Cascader onDropdownVisibleChange={fn} />
 *         <Cascader onDropdownVisibleChange={fn} />
 *     </div>
 * );
 * cascader.fireOpen(cascader.querySelect(container)!);
 * expect(fn).toBeCalledTimes(1);
 * cascader.querySelect(container, 1)?.fireOpen();
 * // The second time is called because of hidden the first one
 * expect(fn).toBeCalledTimes(3);
 */
export declare function querySelect(container: IContainer, index?: number): QuerySelectReturnElement;
/**
 * Returns the `index` element of Cascader's Input
 * @param index the order of Cascader's Input, default is `0`
 * @example
 * const fn = jest.fn();
 *         const { container, getByTestId } = render(
 *             <div>
 *                 <Cascader data-testid="cascader1" onSearch={fn} />
 *                 <Cascader data-testid="cascader2" onSearch={fn} />
 *             </div>
 *         );
 *
 *         expect(cascader.queryInput(container)).toBe(getByTestId('cascader1').querySelector('input'));
 *         expect(cascader.queryInput(container, 1)).toBe(getByTestId('cascader2').querySelector('input'));
 */
export declare function queryInput(container: IContainer, index?: number): QueryInputReturnElement;
/**
 * Returns the Cascader's Dropdown which is not hidden
 * @notice Be aware of the different parentElement affected by getPopupContainer
 * @example
 * render(<Cascader open options={options} />);
 * expect(cascader.queryDropdown(document)).not.toBeNull();
 */
export declare function queryDropdown(container: IContainer): QueryDropdownReturnElement;
/**
 * Returns the `index` element of Menu inside Cascader's Dropdown
 * @param index the order of Menu, default is `0`
 */
export declare function queryMenu(container: IContainer, index?: number): QueryMenuReturnElement;
/**
 * Returns the `index` element of MenuItem inside Cascader's Dropdown
 * @param index the order of MenuItem, default is `0`
 * @example
 * const fn = jest.fn();
 * render(<Cascader open options={options} changeOnSelect onChange={fn} />);
 * fireEvent.click(cascader.queryMenuItem(document)!);
 * expect(fn).toBeCalled();
 */
export declare function queryMenuItem(container: IContainer, index?: number): QueryMenuItemReturnElement;

type QueryReturnElement = MixinElement<{
        query: typeof query;
        querySelect: typeof querySelect;
        queryInput: typeof queryInput;
        queryDropdown: typeof queryDropdown;
        queryMenu: typeof queryMenu;
        queryMenuItem: typeof queryMenuItem;
        fireOpen: typeof fireOpen;
        fireChange: typeof fireChange;
        fireSearch: typeof fireSearch;
        fireClear: typeof fireClear;
    }> | null | undefined;
type QuerySelectReturnElement = MixinElement<{
        query: typeof query;
        querySelect: typeof querySelect;
        queryInput: typeof queryInput;
        queryDropdown: typeof queryDropdown;
        queryMenu: typeof queryMenu;
        queryMenuItem: typeof queryMenuItem;
        fireOpen: typeof fireOpen;
        fireChange: typeof fireChange;
        fireSearch: typeof fireSearch;
        fireClear: typeof fireClear;
    }> | null | undefined;
type QueryInputReturnElement = MixinElement<{
        query: typeof query;
        querySelect: typeof querySelect;
        queryInput: typeof queryInput;
        queryDropdown: typeof queryDropdown;
        queryMenu: typeof queryMenu;
        queryMenuItem: typeof queryMenuItem;
        fireOpen: typeof fireOpen;
        fireChange: typeof fireChange;
        fireSearch: typeof fireSearch;
        fireClear: typeof fireClear;
    }> | null | undefined;
type QueryDropdownReturnElement = MixinElement<{
        query: typeof query;
        querySelect: typeof querySelect;
        queryInput: typeof queryInput;
        queryDropdown: typeof queryDropdown;
        queryMenu: typeof queryMenu;
        queryMenuItem: typeof queryMenuItem;
        fireOpen: typeof fireOpen;
        fireChange: typeof fireChange;
        fireSearch: typeof fireSearch;
        fireClear: typeof fireClear;
    }> | null | undefined;
type QueryMenuReturnElement = MixinElement<{
        query: typeof query;
        querySelect: typeof querySelect;
        queryInput: typeof queryInput;
        queryDropdown: typeof queryDropdown;
        queryMenu: typeof queryMenu;
        queryMenuItem: typeof queryMenuItem;
        fireOpen: typeof fireOpen;
        fireChange: typeof fireChange;
        fireSearch: typeof fireSearch;
        fireClear: typeof fireClear;
    }> | null | undefined;
type QueryMenuItemReturnElement = MixinElement<{
        query: typeof query;
        querySelect: typeof querySelect;
        queryInput: typeof queryInput;
        queryDropdown: typeof queryDropdown;
        queryMenu: typeof queryMenu;
        queryMenuItem: typeof queryMenuItem;
        fireOpen: typeof fireOpen;
        fireChange: typeof fireChange;
        fireSearch: typeof fireSearch;
        fireClear: typeof fireClear;
    }> | null | undefined;
