import type { IContainer, MixinElement } from '../interface';
/**
 * Fires onChange function
 * @example
 * const fn = jest.fn();
 * const { container } = render(<Checkbox.Group options={['Apple', 'Pear', 'Orange']} onChange={fn} />);
 * checkbox.fireChange(container, 0);
 * expect(fn).toBeCalledWith(['Apple']);
 */
export declare function fireChange(container: IContainer, index: number): void;
/**
 * Returns the `index` container
 * @param index default is `0`
 * @example
 * const { container, getByTestId } = render(
 *     <>
 *         <Checkbox data-testid="Checkbox1">Checkbox</Checkbox>
 *         <Checkbox data-testid="Checkbox2">Checkbox</Checkbox>
 *     </>
 * );
 * expect(checkbox.query(container)?.queryInput()).toBe(getByTestId('Checkbox1'));
 * expect(checkbox.query(container, 1)?.queryInput()).toBe(getByTestId('Checkbox2'));
 */
export declare function query(container: IContainer, index?: number): QueryReturnElement;
/**
 * Returns the `index` container for checkbox's group
 * @param index default is `0`
 * @example
 * const { container, getByTestId } = render(
 *     <>
 *         <Checkbox.Group data-testid="Checkbox1" />
 *         <Checkbox.Group data-testid="Checkbox2" />
 *     </>
 * );
 * expect(checkbox.queryGroup(container)).toBe(getByTestId('Checkbox1'));
 * expect(checkbox.queryGroup(container, 1)).toBe(getByTestId('Checkbox2'));
 */
export declare function queryGroup(container: IContainer, index?: number): QueryGroupReturnElement;
/**
 * Returns the `index` input inside Checkbox
 * @param index default is `0`
 * @example
 * const fn = jest.fn();
 * const { container } = render(<Checkbox.Group options={['Apple', 'Pear', 'Orange']} onChange={fn} />);
 * checkbox.fireChange(checkbox.queryInput(container)!, 0);
 * expect(fn).toBeCalledWith(['Apple']);
 */
export declare function queryInput(container: IContainer, index?: number): QueryInputReturnElement;

type QueryReturnElement = MixinElement<{
        query: typeof query;
        queryGroup: typeof queryGroup;
        queryInput: typeof queryInput;
        fireChange: typeof fireChange;
    }> | null | undefined;
type QueryGroupReturnElement = MixinElement<{
        query: typeof query;
        queryGroup: typeof queryGroup;
        queryInput: typeof queryInput;
        fireChange: typeof fireChange;
    }> | null | undefined;
type QueryInputReturnElement = MixinElement<{
        query: typeof query;
        queryGroup: typeof queryGroup;
        queryInput: typeof queryInput;
        fireChange: typeof fireChange;
    }> | null | undefined;
