import type { IContainer, MixinElement } from '../interface';
/**
 * Fires onChange function
 * @example
 * const fn = jest.fn();
 * const items = [
 *     { key: '1', label: 'panel1', children: 'panel1' },
 *     { key: '2', label: 'panel2', children: 'panel2' },
 * ];
 * const { container } = render(<Collapse onChange={fn} items={items} />);
 * collapse.fireChange(container, 0);
 * expect(fn).toBeCalled();
 */
export declare function fireChange(container: IContainer, index: number): void;
/**
 * Returns the `index` container of Collapse
 * @param index default is `0`
 * @example
 * const fn1 = jest.fn();
 * const fn2 = jest.fn();
 * const items = [
 *     { key: '1', label: 'panel1', children: 'panel1' },
 *     { key: '2', label: 'panel2', children: 'panel2' },
 * ];
 * const { container } = render(
 *     <>
 *         <Collapse onChange={fn1} items={items} />
 *         <Collapse onChange={fn2} items={items} />
 *     </>
 * );
 * collapse.query(container, 1)?.fireChange(0);
 * expect(fn1).not.toBeCalled();
 * expect(fn2).toBeCalled();
 */
export declare function query(container: IContainer, index?: number): QueryReturnElement;
/**
 * Returns the `index` of Collapse Panel Content
 *
 * You need to call `fireChange` to expand panel content first
 * @param index default is `0`
 * @example
 * const items = [
 *     { key: '1', label: 'panel1', children: 'content1' },
 *     { key: '2', label: 'panel2', children: 'content2' },
 * ];
 * const { container, getByText } = render(<Collapse items={items} />);
 * // Need to open content panel first
 * collapse.fireChange(container, 0);
 * collapse.fireChange(container, 1);
 * expect(collapse.queryPanelContent(container, 0)).toBe(getByText('content1'));
 * expect(collapse.queryPanelContent(container, 1)).toBe(getByText('content2'));
 */
export declare function queryPanelContent(container: IContainer, index?: number): QueryPanelContentReturnElement;
/**
 * Returns the `index` of Collapse Panel Header
 * @param index default is `0`
 * @example
 * const items = [
 *     { key: '1', label: 'panel1', children: 'panel1' },
 *     { key: '2', label: 'panel2', children: 'panel2' },
 * ];
 * const { container, getByText } = render(<Collapse items={items} />);
 * expect(collapse.queryPanelHeader(container, 0)).toBe(getByText('panel1'));
 * expect(collapse.queryPanelHeader(container, 1)).toBe(getByText('panel2'));
 */
export declare function queryPanelHeader(container: IContainer, index?: number): QueryPanelHeaderReturnElement;

type QueryReturnElement = MixinElement<{
        query: typeof query;
        queryPanelContent: typeof queryPanelContent;
        queryPanelHeader: typeof queryPanelHeader;
        fireChange: typeof fireChange;
    }> | null | undefined;
type QueryPanelContentReturnElement = MixinElement<{
        query: typeof query;
        queryPanelContent: typeof queryPanelContent;
        queryPanelHeader: typeof queryPanelHeader;
        fireChange: typeof fireChange;
    }> | null | undefined;
type QueryPanelHeaderReturnElement = MixinElement<{
        query: typeof query;
        queryPanelContent: typeof queryPanelContent;
        queryPanelHeader: typeof queryPanelHeader;
        fireChange: typeof fireChange;
    }> | null | undefined;
