import type { IContainer, MixinElement } from '../interface';
/**
 * Fires onOpenChange function.
 * Meanwhile, open Dropdown
 * @example
 * const fn = jest.fn();
 * const { container } = render(<DatePicker onOpenChange={fn} />);
 * datePicker.fireOpen(container);
 * expect(fn).toBeCalledTimes(1);
 */
export declare function fireOpen(container: IContainer): void;
/**
 * Fires onOpenChange function.
 * Meanwhile, close dropdown
 * @example
 * const fn1 = jest.fn();
 *         const fn2 = jest.fn();
 *         const { container } = render(<DatePicker onOpenChange={(isOpen) => (isOpen ? fn1() : fn2())} />);
 *         datePicker.fireOpen(container);
 *         expect(fn1).toBeCalled();
 *
 *         datePicker.fireClose(container);
 *         await waitFor(() => {
 *             expect(fn2).toBeCalled();
 *         });
 */
export declare function fireClose(container: IContainer): void;
/**
 * Fires onPanelChange function
 * @notice there are majority ways to call onPanelChange depends on current panel's status
 *
 * The sequence of calling onPanelChange is like
 * `[super prev] -> [prev] -> [next] -> [super next] -> [month] -> [year] -> [decade]`
 *
 * _If you intent to call specific button, call firePanelChange with queryXXX_
 *
 * @param mode defualt is `date`
 * @example
 * const fn = jest.fn();
 * const { container } = render(
 *     <DatePicker
 *         onPanelChange={fn}
 *         value={dateAdaptor('2018-04-13')}
 *         getPopupContainer={(node) => node.parentElement!}
 *     />
 * );
 * datePicker.fireOpen(container);
 * datePicker.firePanelChange(container);
 * expect(fn).lastCalledWith(dateAdaptor('2018-04-13').subtract(1, 'year'), 'date');
 */
export declare function firePanelChange(container: IContainer): void;
/**
 * Fires onChange function or onCalendarChange function for DatePicker.RangePicker
 * @notice May **NOT** call onChange certainly, it depends on whether called firePanelChange before
 * @param text current text on Panel
 * @example
 * const fn = jest.fn();
 *         const { container } = render(
 *             <DatePicker
 *                 onChange={fn}
 *                 value={dateAdaptor('2018-04-13')}
 *                 getPopupContainer={(node) => node.parentElement!}
 *             />
 *         );
 *         datePicker.fireOpen(container);
 *         datePicker.fireChange(container, '24');
 *
 *         expect(fn.mock.calls[0][1]).toBe('2018-04-24');
 */
export declare function fireChange(container: IContainer, text: string): void;
/**
 * Fires onOk function
 * @example
 * const fn = jest.fn();
 *         const { container } = render(
 *             <DatePicker
 *                 showTime
 *                 onOk={fn}
 *                 value={dateAdaptor('2018-04-13 19:18')}
 *                 getPopupContainer={(node) => node.parentElement!}
 *             />
 *         );
 *
 *         datePicker.fireOpen(container);
 *         datePicker.fireOk(container);
 *         expect(fn).toBeCalledTimes(1);
 */
export declare function fireOk(container: IContainer): void;
/**
 * Returns the `index` container of DatePicker
 * @param index defualt is `0`
 * @example
 * const { container, getByTestId } = render(
 *     <>
 *         <DatePicker data-testid="datePicker1" />
 *         <DatePicker data-testid="datePicker2" />
 *     </>
 * );
 * expect(datePicker.query(container)?.queryInput()).toBe(getByTestId('datePicker1'));
 * expect(datePicker.query(container, 1)?.queryInput()).toBe(getByTestId('datePicker2'));
 */
export declare function query(container: IContainer, index?: number): QueryReturnElement;
/**
 * Returns the `index` input element in DatePicker
 * @param index default is `0`
 * @example
 * const { container, getByTestId } = render(
 *     <>
 *         <DatePicker data-testid="datePicker1" />
 *         <DatePicker data-testid="datePicker2" />
 *     </>
 * );
 * expect(datePicker.queryInput(container)).toBe(getByTestId('datePicker1'));
 * expect(datePicker.queryInput(container, 1)).toBe(getByTestId('datePicker2'));
 */
export declare function queryInput(container: IContainer, index?: number): QueryInputReturnElement;
/**
 * Returns the dropdown of DatePicker which is not hidden
 * @example
 * const fn = jest.fn();
 * const { container } = render(
 *     <DatePicker
 *         onChange={fn}
 *         value={dateAdaptor('2018-04-13')}
 *         getPopupContainer={(node) => node.parentElement!}
 *     />
 * );
 * datePicker.fireOpen(container);
 * datePicker.queryDropdown(container)?.fireChange('24');
 * expect((fn.mock.calls[0][0] as ReturnType<typeof dateAdaptor>).isSame(dateAdaptor('2018-04-24'))).toBeTruthy();
 * expect(fn.mock.calls[0][1]).toBe('2018-04-24');
 */
export declare function queryDropdown(container: IContainer): QueryDropdownReturnElement;
/**
 * Returns the `index` super prev button
 * @param index defualt is `0`
 * @example
 * const { container } = render(
 *     <DatePicker value={dateAdaptor('2018-04-13 19:18')} getPopupContainer={(node) => node.parentElement!} />
 * );
 * datePicker.fireOpen(container);
 * expect(datePicker.querySuperPrevButton(container)?.nodeName).toBe('BUTTON');
 */
export declare function querySuperPrevButton(container: IContainer, index?: number): QuerySuperPrevButtonReturnElement;
/**
 * Returns the `index` prev button
 * @param index defualt is `0`
 */
export declare function queryPrevButton(container: IContainer, index?: number): QueryPrevButtonReturnElement;
/**
 * Returns the `index` super next button
 * @param index defualt is `0`
 */
export declare function querySuperNextButton(container: IContainer, index?: number): QuerySuperNextButtonReturnElement;
/**
 * Returns the `index` next button
 * @param index defualt is `0`
 */
export declare function queryNextButton(container: IContainer, index?: number): QueryNextButtonReturnElement;
/**
 * Returns the `index` decade button
 * @param index default is `0`
 */
export declare function queryDecadeButton(container: IContainer, index?: number): QueryDecadeButtonReturnElement;
/**
 * Returns the `index` year button
 * @param index default is `0`
 */
export declare function queryYearButton(container: IContainer, index?: number): QueryYearButtonReturnElement;
/**
 * Returns the `index` month button
 * @param index default is `0`
 */
export declare function queryMonthButton(container: IContainer, index?: number): QueryMonthButtonReturnElement;

type QueryReturnElement = MixinElement<{
        query: typeof query;
        queryInput: typeof queryInput;
        queryDropdown: typeof queryDropdown;
        queryDecadeButton: typeof queryDecadeButton;
        queryMonthButton: typeof queryMonthButton;
        queryNextButton: typeof queryNextButton;
        queryPrevButton: typeof queryPrevButton;
        queryYearButton: typeof queryYearButton;
        querySuperNextButton: typeof querySuperNextButton;
        querySuperPrevButton: typeof querySuperPrevButton;
        fireOpen: typeof fireOpen;
        fireClose: typeof fireClose;
        firePanelChange: typeof firePanelChange;
        fireChange: typeof fireChange;
        fireOk: typeof fireOk;
    }> | null | undefined;
type QueryInputReturnElement = MixinElement<{
        query: typeof query;
        queryInput: typeof queryInput;
        queryDropdown: typeof queryDropdown;
        queryDecadeButton: typeof queryDecadeButton;
        queryMonthButton: typeof queryMonthButton;
        queryNextButton: typeof queryNextButton;
        queryPrevButton: typeof queryPrevButton;
        queryYearButton: typeof queryYearButton;
        querySuperNextButton: typeof querySuperNextButton;
        querySuperPrevButton: typeof querySuperPrevButton;
        fireOpen: typeof fireOpen;
        fireClose: typeof fireClose;
        firePanelChange: typeof firePanelChange;
        fireChange: typeof fireChange;
        fireOk: typeof fireOk;
    }> | null | undefined;
type QueryDropdownReturnElement = MixinElement<{
        query: typeof query;
        queryInput: typeof queryInput;
        queryDropdown: typeof queryDropdown;
        queryDecadeButton: typeof queryDecadeButton;
        queryMonthButton: typeof queryMonthButton;
        queryNextButton: typeof queryNextButton;
        queryPrevButton: typeof queryPrevButton;
        queryYearButton: typeof queryYearButton;
        querySuperNextButton: typeof querySuperNextButton;
        querySuperPrevButton: typeof querySuperPrevButton;
        fireOpen: typeof fireOpen;
        fireClose: typeof fireClose;
        firePanelChange: typeof firePanelChange;
        fireChange: typeof fireChange;
        fireOk: typeof fireOk;
    }> | null | undefined;
type QuerySuperPrevButtonReturnElement = MixinElement<{
        query: typeof query;
        queryInput: typeof queryInput;
        queryDropdown: typeof queryDropdown;
        queryDecadeButton: typeof queryDecadeButton;
        queryMonthButton: typeof queryMonthButton;
        queryNextButton: typeof queryNextButton;
        queryPrevButton: typeof queryPrevButton;
        queryYearButton: typeof queryYearButton;
        querySuperNextButton: typeof querySuperNextButton;
        querySuperPrevButton: typeof querySuperPrevButton;
        fireOpen: typeof fireOpen;
        fireClose: typeof fireClose;
        firePanelChange: typeof firePanelChange;
        fireChange: typeof fireChange;
        fireOk: typeof fireOk;
    }> | null | undefined;
type QueryPrevButtonReturnElement = MixinElement<{
        query: typeof query;
        queryInput: typeof queryInput;
        queryDropdown: typeof queryDropdown;
        queryDecadeButton: typeof queryDecadeButton;
        queryMonthButton: typeof queryMonthButton;
        queryNextButton: typeof queryNextButton;
        queryPrevButton: typeof queryPrevButton;
        queryYearButton: typeof queryYearButton;
        querySuperNextButton: typeof querySuperNextButton;
        querySuperPrevButton: typeof querySuperPrevButton;
        fireOpen: typeof fireOpen;
        fireClose: typeof fireClose;
        firePanelChange: typeof firePanelChange;
        fireChange: typeof fireChange;
        fireOk: typeof fireOk;
    }> | null | undefined;
type QuerySuperNextButtonReturnElement = MixinElement<{
        query: typeof query;
        queryInput: typeof queryInput;
        queryDropdown: typeof queryDropdown;
        queryDecadeButton: typeof queryDecadeButton;
        queryMonthButton: typeof queryMonthButton;
        queryNextButton: typeof queryNextButton;
        queryPrevButton: typeof queryPrevButton;
        queryYearButton: typeof queryYearButton;
        querySuperNextButton: typeof querySuperNextButton;
        querySuperPrevButton: typeof querySuperPrevButton;
        fireOpen: typeof fireOpen;
        fireClose: typeof fireClose;
        firePanelChange: typeof firePanelChange;
        fireChange: typeof fireChange;
        fireOk: typeof fireOk;
    }> | null | undefined;
type QueryNextButtonReturnElement = MixinElement<{
        query: typeof query;
        queryInput: typeof queryInput;
        queryDropdown: typeof queryDropdown;
        queryDecadeButton: typeof queryDecadeButton;
        queryMonthButton: typeof queryMonthButton;
        queryNextButton: typeof queryNextButton;
        queryPrevButton: typeof queryPrevButton;
        queryYearButton: typeof queryYearButton;
        querySuperNextButton: typeof querySuperNextButton;
        querySuperPrevButton: typeof querySuperPrevButton;
        fireOpen: typeof fireOpen;
        fireClose: typeof fireClose;
        firePanelChange: typeof firePanelChange;
        fireChange: typeof fireChange;
        fireOk: typeof fireOk;
    }> | null | undefined;
type QueryDecadeButtonReturnElement = MixinElement<{
        query: typeof query;
        queryInput: typeof queryInput;
        queryDropdown: typeof queryDropdown;
        queryDecadeButton: typeof queryDecadeButton;
        queryMonthButton: typeof queryMonthButton;
        queryNextButton: typeof queryNextButton;
        queryPrevButton: typeof queryPrevButton;
        queryYearButton: typeof queryYearButton;
        querySuperNextButton: typeof querySuperNextButton;
        querySuperPrevButton: typeof querySuperPrevButton;
        fireOpen: typeof fireOpen;
        fireClose: typeof fireClose;
        firePanelChange: typeof firePanelChange;
        fireChange: typeof fireChange;
        fireOk: typeof fireOk;
    }> | null | undefined;
type QueryYearButtonReturnElement = MixinElement<{
        query: typeof query;
        queryInput: typeof queryInput;
        queryDropdown: typeof queryDropdown;
        queryDecadeButton: typeof queryDecadeButton;
        queryMonthButton: typeof queryMonthButton;
        queryNextButton: typeof queryNextButton;
        queryPrevButton: typeof queryPrevButton;
        queryYearButton: typeof queryYearButton;
        querySuperNextButton: typeof querySuperNextButton;
        querySuperPrevButton: typeof querySuperPrevButton;
        fireOpen: typeof fireOpen;
        fireClose: typeof fireClose;
        firePanelChange: typeof firePanelChange;
        fireChange: typeof fireChange;
        fireOk: typeof fireOk;
    }> | null | undefined;
type QueryMonthButtonReturnElement = MixinElement<{
        query: typeof query;
        queryInput: typeof queryInput;
        queryDropdown: typeof queryDropdown;
        queryDecadeButton: typeof queryDecadeButton;
        queryMonthButton: typeof queryMonthButton;
        queryNextButton: typeof queryNextButton;
        queryPrevButton: typeof queryPrevButton;
        queryYearButton: typeof queryYearButton;
        querySuperNextButton: typeof querySuperNextButton;
        querySuperPrevButton: typeof querySuperPrevButton;
        fireOpen: typeof fireOpen;
        fireClose: typeof fireClose;
        firePanelChange: typeof firePanelChange;
        fireChange: typeof fireChange;
        fireOk: typeof fireOk;
    }> | null | undefined;
