import type { IContainer } from 'src/interface';
import { MixinElement } from "../interface";

/**
 * Fires onOpenChange function and close Dropdown
 * @example
 * const fn = jest.fn();
 * const { container } = render(
 *     <Dropdown menu={{ items }} onOpenChange={(open) => !open && fn()}>
 *         <a>button</a>
 *     </Dropdown>
 * );
 * dropdown.fireOpen(container);
 * dropdown.fireCloseWithESC();
 * await waitFor(() => expect(fn).toBeCalled());
 */
export declare function fireCloseWithESC(): void;
/**
 * Fires onOpenChange function and open Dropdown
 * @prerequisite call `jest.useFakeTimers()`
 * @example
 * const fn = jest.fn();
 * const { container } = render(
 *     <Dropdown menu={{ items }} onOpenChange={fn} trigger={['click', 'hover', 'contextMenu']}>
 *         <a>button</a>
 *     </Dropdown>
 * );
 * dropdown.fireOpen(container);
 * await waitFor(() => expect(fn).toBeCalledTimes(1));
 * dropdown.fireOpen(container, 'click');
 * await waitFor(() => expect(fn).toBeCalledTimes(2));
 * dropdown.fireOpen(container, 'contextMenu');
 * await waitFor(() => expect(fn).toBeCalledTimes(3));
 */
export declare function fireOpen(container: IContainer, trigger?: 'hover' | 'click' | 'contextMenu'): void;
/**
 * Fires onClick function of Dropdown Menu Item
 *
 * You need open Dropdown first
 * @example
 * const fn = jest.fn();
 * const { container } = render(
 *     <Dropdown menu={{ items, onClick: fn }} getPopupContainer={(trigger) => trigger.parentElement!}>
 *         <a>button</a>
 *     </Dropdown>
 * );
 * dropdown.fireOpen(container);
 * dropdown.queryDropdownMenu(container)?.fireSelect(1);
 * await waitFor(() => expect(fn.mock.calls[0][0]).toMatchObject({ key: 'item-2' }));
 */
export declare function fireSelect(container: IContainer, index?: number): Error | undefined;
/**
 * Returns the `index` container of Dropdown
 * @param index default is `0`
 * @example
 * const { container, getByTestId } = render(
 *     <>
 *         <Dropdown>
 *             <a data-testid="test1">button1</a>
 *         </Dropdown>
 *         <a>button2</a>
 *         <Dropdown>
 *             <a data-testid="test2">button3</a>
 *         </Dropdown>
 *     </>
 * );
 * expect(dropdown.query(container)).toEqual(getByTestId('test1'));
 * expect(dropdown.query(container, 1)).toEqual(getByTestId('test2'));
 */
export declare function query(container: IContainer, index?: number): QueryReturnElement;
/**
 * Returns doropdown menu
 *
 * You need open Dropdown first
 */
export declare function queryDropdownMenu(container: IContainer): QueryDropdownMenuReturnElement;
/**
 * Returns the `index` container of Dropdown Menu Item
 * @param index default is `0`
 * @example
 * const fn = jest.fn();
 *         const { container } = render(
 *             <Dropdown
 *                 menu={{
 *                     items: [
 *                         { key: 1, label: 'test1' },
 *                         { key: 2, label: 'test2' },
 *                     ],
 *                     onClick: fn,
 *                 }}
 *                 getPopupContainer={(triggerNode) => triggerNode.parentElement!}
 *             >
 *                 <a>button1</a>
 *             </Dropdown>
 *         );
 *         dropdown.fireOpen(container);
 *         await waitFor(() => expect(dropdown.queryDropdownMenuItem(container)?.textContent).toEqual('test1'));
 *         await waitFor(() => expect(dropdown.queryDropdownMenuItem(container, 1)?.textContent).toEqual('test2'));
 *
 *         dropdown.fireSelect(dropdown.queryDropdownMenuItem(container, 1) as HTMLElement);
 *         await waitFor(() => expect(fn).toBeCalledWith(expect.objectContaining({ key: '2' })));
 */
export declare function queryDropdownMenuItem(container: IContainer, index?: number): QueryDropdownMenuItemReturnElement;

type QueryReturnElement = import("src/interface").MixinElement<{
        query: typeof query;
        queryDropdownMenu: typeof queryDropdownMenu;
        queryDropdownMenuItem: typeof queryDropdownMenuItem;
        fireOpen: typeof fireOpen;
        fireSelect: typeof fireSelect;
    }> | null | undefined;
type QueryDropdownMenuReturnElement = import("src/interface").MixinElement<{
        query: typeof query;
        queryDropdownMenu: typeof queryDropdownMenu;
        queryDropdownMenuItem: typeof queryDropdownMenuItem;
        fireOpen: typeof fireOpen;
        fireSelect: typeof fireSelect;
    }> | null | undefined;
type QueryDropdownMenuItemReturnElement = import("src/interface").MixinElement<{
        query: typeof query;
        queryDropdownMenu: typeof queryDropdownMenu;
        queryDropdownMenuItem: typeof queryDropdownMenuItem;
        fireOpen: typeof fireOpen;
        fireSelect: typeof fireSelect;
    }> | null | undefined;
