import type { IContainer, MixinElement } from '../interface';
/**
 * Fires onFocus function
 * @example
 * const fn = jest.fn();
 * const { container } = render(<Input onFocus={fn} />);
 * input.fireFocus(container);
 * expect(fn).toBeCalled();
 */
export declare function fireFocus(container: IContainer): void;
/**
 * Fires onBlur function
 * @example
 * const fn = jest.fn();
 * const { container } = render(<Input onBlur={fn} />);
 * input.fireBlur(container);
 * expect(fn).toBeCalled();
 */
export declare function fireBlur(container: IContainer): void;
/**
 * Fires onChange function
 * @example
 * const fn = jest.fn();
 * const { container } = render(<Input onChange={fn} />);
 * input.fireChange(container, 'test');
 * expect(fn).toBeCalled();
 */
export declare function fireChange(container: IContainer, value: any): void;
/**
 * Fires onClear function
 * @example
 * const fn = jest.fn();
 * const { container } = render(<Input allowClear defaultValue="test" onChange={fn} />);
 * input.fireClear(container);
 * expect(fn).toBeCalled();
 */
export declare function fireClear(container: IContainer): void;
/**
 * Fires onPressEnter function
 * @example
 * const fn = jest.fn();
 * const { container } = render(<Input.Search onSearch={fn} />);
 * input.fireSearch(container);
 * expect(fn).toBeCalled();
 */
export declare function firePressEnter(container: IContainer): void;
/**
 * Fires onSearch function
 */
export declare function fireSearch(container: IContainer): void;
/**
 * Returns the `index` of input element
 * @example
 * const { container, getByTestId } = render(
 *     <div>
 *         <Input data-testid="input1" />
 *         <Input data-testid="input2" />
 *     </div>
 * );
 * expect(input.query(container)).toBe(getByTestId('input1'));
 * expect(input.query(container, 1)).toBe(getByTestId('input2'));
 */
export declare function query(container: IContainer, index?: number): QueryReturnElement;
/**
 * Returns the `input.search` search button
 * @example
 * const fn = jest.fn();
 * const { container } = render(<Input.Search onSearch={fn} />);
 * fireEvent.click(input.querySearchButton(container)!);
 * expect(fn).toBeCalled();
 */
export declare function querySearchButton(container: IContainer, index?: number): QuerySearchButtonReturnElement;
export * as textarea from './textarea';

type QueryReturnElement = MixinElement<{
        query: typeof query;
        querySearchButton: typeof querySearchButton;
        fireFocus: typeof fireFocus;
        fireBlur: typeof fireBlur;
        fireChange: typeof fireChange;
        fireClear: typeof fireClear;
        firePressEnter: typeof firePressEnter;
        fireSearch: typeof fireSearch;
    }> | null | undefined;
type QuerySearchButtonReturnElement = MixinElement<{
        query: typeof query;
        querySearchButton: typeof querySearchButton;
        fireFocus: typeof fireFocus;
        fireBlur: typeof fireBlur;
        fireChange: typeof fireChange;
        fireClear: typeof fireClear;
        firePressEnter: typeof firePressEnter;
        fireSearch: typeof fireSearch;
    }> | null | undefined;
