import type { IContainer, MixinElement } from '../interface';
/**
 * Fires onChange function
 * @example
 * const fn = jest.fn();
 *         const { container } = render(<InputNumber onChange={fn} />);
 *         inputNumber.fireChange(container, 1);
 *
 *         expect(fn).toBeCalledWith(1);
 */
export declare function fireChange(container: IContainer, value: any): void;
/**
 * Fires onStep function
 * @example
 * const fn = jest.fn();
 *         const { container } = render(<InputNumber onStep={fn} defaultValue={1} />);
 *         inputNumber.fireStepUp(container);
 *
 *         expect(fn).toBeCalledWith(2, expect.objectContaining({ type: 'up' }));
 */
export declare function fireStepUp(container: IContainer): void;
/**
 * Fires onStep function
 * @example
 * const fn = jest.fn();
 *         const { container } = render(<InputNumber onStep={fn} defaultValue={1} />);
 *         inputNumber.fireStepDown(container);
 *
 *         expect(fn).toBeCalledWith(0, expect.objectContaining({ type: 'down' }));
 */
export declare function fireStepDown(container: IContainer): void;
/**
 * Fires onPressEnter function
 * @example
 * const fn = jest.fn();
 *         const { container } = render(<InputNumber onPressEnter={fn} />);
 *         inputNumber.firePressEnter(container);
 *
 *         expect(fn).toBeCalled();
 */
export declare function firePressEnter(container: IContainer): void;
/**
 * Fires onFocus function
 * @example
 * const fn = jest.fn();
 *         const { container } = render(<InputNumber onFocus={fn} />);
 *         inputNumber.fireFocus(container);
 *
 *         expect(fn).toBeCalled();
 */
export declare function fireFocus(container: IContainer): void;
/**
 * Fires onBlur function
 * @example
 * const fn = jest.fn();
 *         const { container } = render(<InputNumber onBlur={fn} />);
 *         inputNumber.fireBlur(container);
 *
 *         expect(fn).toBeCalled();
 */
export declare function fireBlur(container: IContainer): void;
/**
 * Returns the container of InputNumber
 * @example
 * const { container } = render(
 *     <>
 *         <InputNumber className="test1" />
 *         <InputNumber className="test2" />
 *     </>
 * );
 * expect(inputNumber.query(container)?.className).toEqual(expect.stringContaining('test1'));
 * expect(inputNumber.query(container, 1)?.className).toEqual(expect.stringContaining('test2'));
 */
export declare function query(container: IContainer, index?: number): QueryReturnElement;
/**
 * Returns the input element of InputNumber
 * @example
 * const { container } = render(<InputNumber />);
 * expect(inputNumber.queryInput(container)?.nodeName).toBe('INPUT');
 */
export declare function queryInput(container: IContainer, index?: number): QueryInputReturnElement;

type QueryReturnElement = MixinElement<{
        query: typeof query;
        queryInput: typeof queryInput;
        fireChange: typeof fireChange;
        fireStepUp: typeof fireStepUp;
        fireStepDown: typeof fireStepDown;
        firePressEnter: typeof firePressEnter;
        fireFocus: typeof fireFocus;
        fireBlur: typeof fireBlur;
    }> | null | undefined;
type QueryInputReturnElement = MixinElement<{
        query: typeof query;
        queryInput: typeof queryInput;
        fireChange: typeof fireChange;
        fireStepUp: typeof fireStepUp;
        fireStepDown: typeof fireStepDown;
        firePressEnter: typeof firePressEnter;
        fireFocus: typeof fireFocus;
        fireBlur: typeof fireBlur;
    }> | null | undefined;
