import type { IContainer, MixinElement } from '../interface';
/**
 * Fires onClick function
 * @example
 * const fn = jest.fn();
 *         act(() => {
 *             Notification.info({
 *                 message: 'This is a notification message',
 *                 duration: 0,
 *                 onClick: fn,
 *             });
 *         });
 *         await waitFor(() => {
 *             expect(notification.query(document.body)).toBeTruthy();
 *         });
 *         notification.fireClick(document.body);
 *         expect(fn).toHaveBeenCalled();
 *
 *         act(() => {
 *             Notification.destroy();
 *         });
 */
export declare function fireClick(container: IContainer): void;
/**
 * Fires onClose function by click close icon
 *
 * You need set duration to `0`
 * @example
 * const fn = jest.fn();
 * act(() => {
 *     Notification.info({
 *         message: 'This is a notification message',
 *         duration: 0,
 *         closeIcon: <span>关闭</span>,
 *         onClose: fn,
 *     });
 * });
 * await waitFor(() => {
 *     expect(notification.query(document.body)).toBeTruthy();
 * });
 * notification.fireClose(document.body);
 * expect(fn).toBeCalled();
 */
export declare function fireClose(container: IContainer): void;
/**
 * Returns the `index` container of Notification
 * @param index default is `0`
 * @example
 * act(() => {
 *     Notification.info({
 *         message: 'This is a notification message',
 *         className: 'test1',
 *         duration: 0,
 *     });
 * });
 * await waitFor(() => {
 *     expect(notification.query(document.body)).toBeTruthy();
 * });
 * expect(notification.query(document.body)?.className).toContain('test1');
 */
export declare function query(container: IContainer, index?: number): QueryReturnElement;

type QueryReturnElement = MixinElement<{
        query: typeof query;
        fireClick: typeof fireClick;
        fireClose: typeof fireClose;
    }> | null | undefined;
