import * as button from '../button';
import type { IContainer, MixinElement } from '../interface';
/**
 * Open popconfirm
 * @example
 * const fn = jest.fn();
 * const { container } = render(
 *     <Popconfirm title="test" onOpenChange={fn} getPopupContainer={(node) => node.parentElement!}>
 *         <Button danger>Delete</Button>
 *     </Popconfirm>
 * );
 * confirm.fireOpen(button.query(container)!);
 * expect(fn).toBeCalledTimes(1);
 */
export declare function fireOpen(trigger: HTMLElement): void;
/**
 * Fires onCancel function
 * @example
 * const fn = jest.fn();
 * const { container } = render(
 *     <Popconfirm title="test" onCancel={fn} getPopupContainer={(node) => node.parentElement!}>
 *         <Button danger>Delete</Button>
 *     </Popconfirm>
 * );
 * confirm.fireOpen(button.query(container)!);
 * confirm.fireCancel(container);
 * expect(fn).toBeCalled();
 */
export declare function fireCancel(container: IContainer): void;
/**
 * Fires onConfirm function
 * @example
 * const fn = jest.fn();
 * const { container } = render(
 *     <Popconfirm title="test" onConfirm={fn} getPopupContainer={(node) => node.parentElement!}>
 *         <Button danger>Delete</Button>
 *     </Popconfirm>
 * );
 * confirm.fireOpen(button.query(container)!);
 * confirm.fireConfirm(container);
 * expect(fn).toBeCalled();
 */
export declare function fireConfirm(container: IContainer): void;
/**
 * Returns the container element
 * @example
 * const { container } = render(
 *     <Popconfirm title="test" getPopupContainer={(node) => node.parentElement!}>
 *         <Button danger>Delete</Button>
 *     </Popconfirm>
 * );
 * confirm.fireOpen(button.query(container)!);
 * expect(confirm.query(container)).not.toBeNull();
 */
export declare function query(container: IContainer, index?: number): QueryReturnElement;
/**
 * Returns the buttons element
 * @example
 * const { container } = render(
 *     <Popconfirm title="test" getPopupContainer={(node) => node.parentElement!}>
 *         <Button danger>Delete</Button>
 *     </Popconfirm>
 * );
 * confirm.fireOpen(button.query(container)!);
 * expect(confirm.queryButtons(container)).not.toBeNull();
 */
export declare function queryButtons(container: IContainer, index?: number): QueryButtonsReturnElement;
/**
 * Returns the cancel button inside buttons
 * @example
 * const fn = jest.fn();
 * const { container } = render(
 *     <Popconfirm title="test" onCancel={fn} getPopupContainer={(node) => node.parentElement!}>
 *         <Button danger>Delete</Button>
 *     </Popconfirm>
 * );
 * confirm.fireOpen(button.query(container)!);
 * confirm.fireCancel(confirm.queryCancelButton(container)!);
 * expect(fn).toBeCalled();
 */
export declare function queryCancelButton(container: IContainer, index?: number): QueryCancelButtonReturnElement;
/**
 * Returns the confirm button inside buttons
 * @example
 * const fn = jest.fn();
 * const { container } = render(
 *     <Popconfirm title="test" onConfirm={fn} getPopupContainer={(node) => node.parentElement!}>
 *         <Button danger>Delete</Button>
 *     </Popconfirm>
 * );
 * confirm.fireOpen(button.query(container)!);
 * confirm.fireConfirm(confirm.queryConfirmButton(container)!);
 * expect(fn).toBeCalled();
 */
export declare function queryConfirmButton(container: IContainer, index?: number): QueryConfirmButtonReturnElement;

type QueryReturnElement = MixinElement<{
        query: typeof query;
        queryButtons: typeof queryButtons;
        queryCancelButton: typeof queryCancelButton;
        queryConfirmButton: typeof queryConfirmButton;
        fireCancel: typeof fireCancel;
        fireConfirm: typeof fireConfirm;
    }> | null | undefined;
type QueryButtonsReturnElement = MixinElement<{
        query: typeof query;
        queryButtons: typeof queryButtons;
        queryCancelButton: typeof queryCancelButton;
        queryConfirmButton: typeof queryConfirmButton;
        fireCancel: typeof fireCancel;
        fireConfirm: typeof fireConfirm;
    }> | null | undefined;
type QueryCancelButtonReturnElement = HTMLButtonElement | MixinElement<{
        query: typeof button.query;
        fireClick: typeof button.fireClick;
    }> | null | undefined;
type QueryConfirmButtonReturnElement = HTMLButtonElement | MixinElement<{
        query: typeof button.query;
        fireClick: typeof button.fireClick;
    }> | null | undefined;
