import type { IContainer, MixinElement } from '../interface';
/**
 * Fires onSearch function
 * @example
 * const fn = jest.fn();
 * const { container } = render(<Select onSearch={fn} showSearch options={[{ label: 1, value: 1 }]} />);
 * select.fireSearch(container, 'test');
 * expect(fn).toBeCalled();
 */
export declare function fireSearch(container: IContainer, value: any): void;
/**
 * Fires onDropdownVisibleChange function.
 * Meanwhile, open Dropdown
 * @example
 * const fn = jest.fn();
 * const { container } = render(<Select onDropdownVisibleChange={fn} options={[{ label: 1, value: 1 }]} />);
 * select.fireOpen(container);
 * expect(fn).toBeCalledWith(true);
 */
export declare function fireOpen(container: IContainer): void;
/**
 * Fires onSelect function
 * @param container Be aware of the dropdown's renderRoot
 * @param index Select the `index` options
 * @example
 * const fn = jest.fn();
 * const { container } = render(
 *     <Select onChange={fn} getPopupContainer={(node) => node.parentNode} options={[{ label: 1, value: 1 }]} />
 * );
 * select.fireOpen(container);
 * select.fireSelect(container, 0);
 * expect(fn).toBeCalled();
 */
export declare function fireSelect(container: IContainer, index: number): void;
/**
 * Fires onDeselect function, **ONLY** works for tag or multiply mode
 * @param index Deselect the `index` tag
 * @example
 * const fn = jest.fn();
 * const { container } = render(
 *     <Select onDeselect={fn} defaultValue="1" allowClear mode="tags" options={[{ label: 1, value: '1' }]} />
 * );
 * select.fireDeSelect(container, 0);
 * expect(fn).toBeCalled();
 */
export declare function fireDeSelect(container: IContainer, index: number): void;
/**
 * Fires onFocus function
 * @example
 * const fn = jest.fn();
 * const { container } = render(<Select onFocus={fn} options={[{ label: 1, value: 1 }]} />);
 * select.fireFocus(container);
 * expect(fn).toBeCalled();
 */
export declare function fireFocus(container: IContainer): void;
/**
 * Fires onBlur function
 * @example
 * const fn = jest.fn();
 * const { container } = render(<Select onBlur={fn} options={[{ label: 1, value: 1 }]} />);
 * select.fireFocus(container);
 * select.fireBlur(container);
 * expect(fn).toBeCalled();
 */
export declare function fireBlur(container: IContainer): void;
/**
 * Fires onClear function
 * @notice Be aware of value before call fireClear
 * @example
 * const fn = jest.fn();
 * const { container } = render(
 *     <Select onClear={fn} defaultValue={1} allowClear options={[{ label: 1, value: 1 }]} />
 * );
 * select.fireClear(container);
 * expect(fn).toBeCalled();
 */
export declare function fireClear(container: IContainer): void;
/**
 * Returns the `index` Select's container
 * @param index default is 0
 * @example
 * const { container, getByTestId } = render(
 *     <>
 *         <Select data-testid="select1" />
 *         <Select data-testid="select2" />
 *     </>
 * );
 * expect(select.query(container)).toBe(getByTestId('select1'));
 * expect(select.query(container, 1)).toBe(getByTestId('select2'));
 */
export declare function query(container: IContainer, index?: number): QueryReturnElement;
/**
 * Returns the `index` Input inside Select
 * @param index default is 0
 * @example
 * const fn1 = jest.fn();
 * const fn2 = jest.fn();
 * const { container } = render(
 *     <>
 *         <Select showSearch onSearch={fn1} />
 *         <Select showSearch onSearch={fn2} />
 *     </>
 * );
 * select.fireSearch(select.queryInput(container)!, 'test1');
 * select.queryInput(container, 1)?.fireSearch('test2');
 * expect(fn1).toBeCalledWith('test1');
 * expect(fn2).toBeCalledWith('test2');
 */
export declare function queryInput(container: IContainer, index?: number): QueryInputReturnElement;
/**
 * Returns the `index` Selector dom inside Select,
 * the main element to call fireOpen
 * @param index default is 0
 * @example
 * const fn1 = jest.fn();
 * const fn2 = jest.fn();
 * const { container } = render(
 *     <>
 *         <Select onDropdownVisibleChange={fn1} />
 *         <Select onDropdownVisibleChange={fn2} />
 *     </>
 * );
 * select.fireOpen(select.querySelectorWrapper(container)!);
 * expect(fn1).toBeCalledTimes(1);
 * select.querySelectorWrapper(container, 1)?.fireOpen();
 * expect(fn2).toBeCalledTimes(1);
 */
export declare function querySelectorWrapper(container: IContainer, index?: number): QuerySelectorWrapperReturnElement;
/**
 * Returns the Select Dropdown which is not hidden
 * @example
 * const fn1 = jest.fn();
 *         const fn2 = jest.fn();
 *         const { container } = render(
 *             <>
 *                 <Select options={[{ label: 1, value: 1 }]} onSelect={fn1} />
 *                 <Select options={[{ label: 2, value: 2 }]} onSelect={fn2} />
 *             </>
 *         );
 *         select.fireOpen(select.querySelectorWrapper(container)!);
 *         select.fireSelect(select.queryDropdown(document)!, 0);
 *         expect(fn1).toBeCalledWith(1, expect.objectContaining({ label: 1, value: 1 }));
 *
 *         select.querySelectorWrapper(container, 1)?.fireOpen();
 *         select.queryDropdown(document)?.fireSelect(0);
 *         expect(fn2).toBeCalledWith(2, expect.objectContaining({ label: 2, value: 2 }));
 */
export declare function queryDropdown(container: IContainer): QueryDropdownReturnElement;
/**
 * Returns the `index` Option for Select
 * @param index default is 0
 * @example
 * const fn = jest.fn();
 * const { container } = render(
 *     <Select
 *         options={[
 *             { label: 1, value: 1 },
 *             { label: 2, value: 2 },
 *         ]}
 *         getPopupContainer={(node) => node.parentNode}
 *         onSelect={fn}
 *     />
 * );
 * select.fireOpen(container);
 * select.fireSelect(select.queryOption(container, 1)!, 0);
 * expect(fn).toBeCalledWith(2, expect.objectContaining({ label: 2, value: 2 }));
 */
export declare function queryOption(container: IContainer, index?: number): QueryOptionReturnElement;
/**
 * Returns the `index` clear icon's container
 */
export declare function queryClear(container: IContainer, index?: number): QueryClearReturnElement;

type QueryReturnElement = MixinElement<{
        query: typeof query;
        queryInput: typeof queryInput;
        querySelectorWrapper: typeof querySelectorWrapper;
        queryDropdown: typeof queryDropdown;
        queryOption: typeof queryOption;
        queryClear: typeof queryClear;
        fireSearch: typeof fireSearch;
        fireOpen: typeof fireOpen;
        fireSelect: typeof fireSelect;
        fireDeSelect: typeof fireDeSelect;
        fireFocus: typeof fireFocus;
        fireBlur: typeof fireBlur;
        fireClear: typeof fireClear;
    }> | null | undefined;
type QueryInputReturnElement = MixinElement<{
        query: typeof query;
        queryInput: typeof queryInput;
        querySelectorWrapper: typeof querySelectorWrapper;
        queryDropdown: typeof queryDropdown;
        queryOption: typeof queryOption;
        queryClear: typeof queryClear;
        fireSearch: typeof fireSearch;
        fireOpen: typeof fireOpen;
        fireSelect: typeof fireSelect;
        fireDeSelect: typeof fireDeSelect;
        fireFocus: typeof fireFocus;
        fireBlur: typeof fireBlur;
        fireClear: typeof fireClear;
    }> | null | undefined;
type QuerySelectorWrapperReturnElement = MixinElement<{
        query: typeof query;
        queryInput: typeof queryInput;
        querySelectorWrapper: typeof querySelectorWrapper;
        queryDropdown: typeof queryDropdown;
        queryOption: typeof queryOption;
        queryClear: typeof queryClear;
        fireSearch: typeof fireSearch;
        fireOpen: typeof fireOpen;
        fireSelect: typeof fireSelect;
        fireDeSelect: typeof fireDeSelect;
        fireFocus: typeof fireFocus;
        fireBlur: typeof fireBlur;
        fireClear: typeof fireClear;
    }> | null | undefined;
type QueryDropdownReturnElement = MixinElement<{
        query: typeof query;
        queryInput: typeof queryInput;
        querySelectorWrapper: typeof querySelectorWrapper;
        queryDropdown: typeof queryDropdown;
        queryOption: typeof queryOption;
        queryClear: typeof queryClear;
        fireSearch: typeof fireSearch;
        fireOpen: typeof fireOpen;
        fireSelect: typeof fireSelect;
        fireDeSelect: typeof fireDeSelect;
        fireFocus: typeof fireFocus;
        fireBlur: typeof fireBlur;
        fireClear: typeof fireClear;
    }> | null | undefined;
type QueryOptionReturnElement = MixinElement<{
        query: typeof query;
        queryInput: typeof queryInput;
        querySelectorWrapper: typeof querySelectorWrapper;
        queryDropdown: typeof queryDropdown;
        queryOption: typeof queryOption;
        queryClear: typeof queryClear;
        fireSearch: typeof fireSearch;
        fireOpen: typeof fireOpen;
        fireSelect: typeof fireSelect;
        fireDeSelect: typeof fireDeSelect;
        fireFocus: typeof fireFocus;
        fireBlur: typeof fireBlur;
        fireClear: typeof fireClear;
    }> | null | undefined;
type QueryClearReturnElement = MixinElement<{
        query: typeof query;
        queryInput: typeof queryInput;
        querySelectorWrapper: typeof querySelectorWrapper;
        queryDropdown: typeof queryDropdown;
        queryOption: typeof queryOption;
        queryClear: typeof queryClear;
        fireSearch: typeof fireSearch;
        fireOpen: typeof fireOpen;
        fireSelect: typeof fireSelect;
        fireDeSelect: typeof fireDeSelect;
        fireFocus: typeof fireFocus;
        fireBlur: typeof fireBlur;
        fireClear: typeof fireClear;
    }> | null | undefined;
