import type { IContainer, MixinElement } from '../interface';
/**
 * Fires onDropdownVisibleChange function
 * @example
 * const fn = jest.fn();
 *         const { container } = render(<TreeSelect onDropdownVisibleChange={fn} />);
 *
 *         treeSelect.fireOpen(container);
 *         expect(fn).toBeCalled();
 */
export declare function fireOpen(container: IContainer): void;
/**
 * Fires onSearch function
 * @example
 * const fn = jest.fn();
 *         const { container } = render(<TreeSelect onSearch={fn} />);
 *
 *         treeSelect.fireSearch(container, 'test');
 *         expect(fn).toBeCalled();
 */
export declare function fireSearch(container: IContainer, value: any): void;
/**
 * Fires onSelect function
 *
 * Need expand tree node first
 * @example
 * const fn = jest.fn();
 *         const treeData = [
 *             {
 *                 title: 'Node1',
 *                 value: '0-0',
 *                 children: [
 *                     {
 *                         title: 'Child Node1',
 *                         value: '0-0-1',
 *                     },
 *                     {
 *                         title: 'Child Node2',
 *                         value: '0-0-2',
 *                     },
 *                 ],
 *             },
 *             {
 *                 title: 'Node2',
 *                 value: '0-1',
 *             },
 *         ];
 *         const { container } = render(
 *             <TreeSelect
 *                 treeData={treeData}
 *                 treeDefaultExpandAll
 *                 getPopupContainer={(node) => node.parentNode}
 *                 onSelect={fn}
 *             />
 *         );
 *
 *         treeSelect.fireOpen(container);
 *         treeSelect.fireSelect(container, 3);
 *         expect(fn).toBeCalled();
 */
export declare function fireSelect(container: IContainer, index: number): void;
/**
 * Fires onTreeExpand function
 * @example
 * const fn = jest.fn();
 *         const treeData = [
 *             {
 *                 title: 'Node1',
 *                 value: '0-0',
 *                 children: [
 *                     {
 *                         title: 'Child Node1',
 *                         value: '0-0-1',
 *                     },
 *                     {
 *                         title: 'Child Node2',
 *                         value: '0-0-2',
 *                     },
 *                 ],
 *             },
 *             {
 *                 title: 'Node2',
 *                 value: '0-1',
 *             },
 *         ];
 *         const { container } = render(
 *             <TreeSelect treeData={treeData} getPopupContainer={(node) => node.parentNode} onTreeExpand={fn} />
 *         );
 *
 *         treeSelect.fireOpen(container);
 *         treeSelect.fireTreeExpand(container, 0);
 *         expect(fn).toBeCalled();
 */
export declare function fireTreeExpand(container: IContainer, index: number): void;
/**
 * Returns the `index` element of TreeSelect
 * @param index default is 0
 * @example
 * const { container, getByTestId } = render(
 *     <>
 *         <TreeSelect data-testid="tree1" />
 *         <TreeSelect data-testid="tree2" />
 *     </>
 * );
 * expect(treeSelect.query(container)).toBe(getByTestId('tree1'));
 * expect(treeSelect.query(container, 1)).toBe(getByTestId('tree2'));
 */
export declare function query(container: IContainer, index?: number): QueryReturnElement;
/**
 * Returns the `index` element of Input inside TreeSelect
 * @param index default is 0
 * @example
 * const fn1 = jest.fn();
 * const fn2 = jest.fn();
 * const { container } = render(
 *     <>
 *         <TreeSelect onSearch={fn1} />
 *         <TreeSelect showSearch onSearch={fn2} />
 *     </>
 * );
 * treeSelect.fireSearch(treeSelect.queryInput(container)!, 'test1');
 * treeSelect.fireSearch(treeSelect.queryInput(container, 1)!, 'test2');
 * expect(fn1).toBeCalledWith('test1');
 * expect(fn2).toBeCalledWith('test2');
 */
export declare function queryInput(container: IContainer, index?: number): QueryInputReturnElement;
/**
 * Returns the `index` Selector dom inside Select,
 * the main element to call fireOpen
 * @param index default is 0
 * @example
 * const fn1 = jest.fn();
 * const fn2 = jest.fn();
 * const { container } = render(
 *     <>
 *         <TreeSelect onDropdownVisibleChange={fn1} />
 *         <TreeSelect onDropdownVisibleChange={fn2} />
 *     </>
 * );
 * treeSelect.fireOpen(treeSelect.querySelectorWrapper(container)!);
 * expect(fn1).toBeCalledTimes(1);
 * treeSelect.fireOpen(treeSelect.querySelectorWrapper(container, 1)!);
 * expect(fn2).toBeCalledTimes(1);
 */
export declare function querySelectorWrapper(container: IContainer, index?: number): QuerySelectorWrapperReturnElement;
/**
 * Returns the Tree Select Dropdown which is not hidden
 * @example
 * const treeData = [
 *     {
 *         title: 'Node1',
 *         value: '0-0',
 *         children: [
 *             {
 *                 title: 'Child Node1',
 *                 value: '0-0-1',
 *             },
 *             {
 *                 title: 'Child Node2',
 *                 value: '0-0-2',
 *             },
 *         ],
 *     },
 * ];
 * const fn = jest.fn();
 * const { container } = render(<TreeSelect treeData={treeData} onSelect={fn} />);
 * treeSelect.fireOpen(treeSelect.querySelectorWrapper(container)!);
 * treeSelect.fireSelect(treeSelect.queryDropdown(document)!, 0);
 * expect(fn).toBeCalledWith('0-0', expect.objectContaining({ title: 'Node1', value: '0-0' }));
 */
export declare function queryDropdown(container: IContainer): QueryDropdownReturnElement;
/**
 * Returns the `index` Option for Select
 *
 * Need expand tree node first
 *
 * @param index default is 0
 * @example
 * const treeData = [
 *     {
 *         title: 'Node1',
 *         value: '0-0',
 *         children: [
 *             {
 *                 title: 'Child Node1',
 *                 value: '0-0-1',
 *             },
 *             {
 *                 title: 'Child Node2',
 *                 value: '0-0-2',
 *             },
 *         ],
 *     },
 * ];
 * const fn = jest.fn();
 * const { container } = render(
 *     <TreeSelect
 *         treeData={treeData}
 *         getPopupContainer={(node) => node.parentNode}
 *         treeDefaultExpandAll
 *         onSelect={fn}
 *     />
 * );
 * treeSelect.fireOpen(container);
 * treeSelect.fireSelect(treeSelect.queryOption(container, 2)!, 0);
 * expect(fn).toBeCalledWith('0-0-2', expect.objectContaining({ title: 'Child Node2', value: '0-0-2' }));
 */
export declare function queryOption(container: IContainer, index?: number): QueryOptionReturnElement;
/**
 * Returns the `index` clear icon's container
 */
export declare function queryClear(container: IContainer, index?: number): QueryClearReturnElement;

type QueryReturnElement = MixinElement<{
        query: typeof query;
        queryInput: typeof queryInput;
        queryDropdown: typeof queryDropdown;
        queryOption: typeof queryOption;
        querySelectorWrapper: typeof querySelectorWrapper;
        queryClear: typeof queryClear;
        fireOpen: typeof fireOpen;
        fireSearch: typeof fireSearch;
        fireSelect: typeof fireSelect;
        fireTreeExpand: typeof fireTreeExpand;
    }> | null | undefined;
type QueryInputReturnElement = MixinElement<{
        query: typeof query;
        queryInput: typeof queryInput;
        queryDropdown: typeof queryDropdown;
        queryOption: typeof queryOption;
        querySelectorWrapper: typeof querySelectorWrapper;
        queryClear: typeof queryClear;
        fireOpen: typeof fireOpen;
        fireSearch: typeof fireSearch;
        fireSelect: typeof fireSelect;
        fireTreeExpand: typeof fireTreeExpand;
    }> | null | undefined;
type QuerySelectorWrapperReturnElement = MixinElement<{
        query: typeof query;
        queryInput: typeof queryInput;
        queryDropdown: typeof queryDropdown;
        queryOption: typeof queryOption;
        querySelectorWrapper: typeof querySelectorWrapper;
        queryClear: typeof queryClear;
        fireOpen: typeof fireOpen;
        fireSearch: typeof fireSearch;
        fireSelect: typeof fireSelect;
        fireTreeExpand: typeof fireTreeExpand;
    }> | null | undefined;
type QueryDropdownReturnElement = MixinElement<{
        query: typeof query;
        queryInput: typeof queryInput;
        queryDropdown: typeof queryDropdown;
        queryOption: typeof queryOption;
        querySelectorWrapper: typeof querySelectorWrapper;
        queryClear: typeof queryClear;
        fireOpen: typeof fireOpen;
        fireSearch: typeof fireSearch;
        fireSelect: typeof fireSelect;
        fireTreeExpand: typeof fireTreeExpand;
    }> | null | undefined;
type QueryOptionReturnElement = MixinElement<{
        query: typeof query;
        queryInput: typeof queryInput;
        queryDropdown: typeof queryDropdown;
        queryOption: typeof queryOption;
        querySelectorWrapper: typeof querySelectorWrapper;
        queryClear: typeof queryClear;
        fireOpen: typeof fireOpen;
        fireSearch: typeof fireSearch;
        fireSelect: typeof fireSelect;
        fireTreeExpand: typeof fireTreeExpand;
    }> | null | undefined;
type QueryClearReturnElement = MixinElement<{
        query: typeof query;
        queryInput: typeof queryInput;
        queryDropdown: typeof queryDropdown;
        queryOption: typeof queryOption;
        querySelectorWrapper: typeof querySelectorWrapper;
        queryClear: typeof queryClear;
        fireOpen: typeof fireOpen;
        fireSearch: typeof fireSearch;
        fireSelect: typeof fireSelect;
        fireTreeExpand: typeof fireTreeExpand;
    }> | null | undefined;
