import type { IContainer, MixinElement } from '../interface';
import * as select from '../select';
/**
 * Fires onSearch function
 * @example
 * const fn = jest.fn();
 * const { container } = render(<AutoComplete onSearch={fn} showSearch options={[{ label: 'a', value: 'a' }]} />);
 * autoComplete.fireSearch(container, 'test');
 * expect(fn).toBeCalled();
 */
export declare function fireSearch(container: IContainer, value: any): void;
/**
 * Fires onDropdownVisibleChange function.
 * Meanwhile, open Dropdown
 * @example
 * const fn = jest.fn();
 * const { container } = render(
 *     <AutoComplete onDropdownVisibleChange={fn} options={[{ label: 'a', value: 'a' }]} />
 * );
 * autoComplete.fireOpen(container);
 * expect(fn).toBeCalledWith(true);
 */
export declare function fireOpen(container: IContainer): void;
/**
 * Fires onSelect function
 * @example
 * const fn = jest.fn();
 * const { container } = render(
 *     <AutoComplete
 *         onChange={fn}
 *         getPopupContainer={(node) => node.parentNode}
 *         options={[{ label: 'a', value: 'a' }]}
 *     />
 * );
 * autoComplete.fireOpen(container);
 * autoComplete.fireSelect(container, 0);
 * expect(fn).toBeCalled();
 */
export declare function fireSelect(container: IContainer, index: number): void;
/**
 * Fires onFocus function
 * @example
 * const fn = jest.fn();
 * const { container } = render(<AutoComplete onFocus={fn} options={[{ label: 'a', value: 'a' }]} />);
 * autoComplete.fireFocus(container);
 * expect(fn).toBeCalled();
 */
export declare function fireFocus(container: IContainer): void;
/**
 * Fires onBlur function
 * @example
 * const fn = jest.fn();
 * const { container } = render(<AutoComplete onBlur={fn} options={[{ label: 'a', value: 'a' }]} />);
 * autoComplete.fireFocus(container);
 * autoComplete.fireBlur(container);
 * expect(fn).toBeCalled();
 */
export declare function fireBlur(container: IContainer): void;
/**
 * Fires onClear function
 * @example
 * const fn = jest.fn();
 * const { container } = render(
 *     <AutoComplete onClear={fn} defaultValue={1} allowClear options={[{ label: 'a', value: 'a' }]} />
 * );
 * autoComplete.fireClear(container);
 * expect(fn).toBeCalled();
 */
export declare function fireClear(container: IContainer): void;
/**
 * Returns the `index` container of AutoComplete
 * @param index default is `0`
 * @example
 * const { container, getByTestId } = render(
 *     <>
 *         <AutoComplete data-testid="autoComplete1" />
 *         <AutoComplete data-testid="autoComplete2" />
 *     </>
 * );
 * expect(autoComplete.query(container)).toBe(getByTestId('autoComplete1'));
 * expect(autoComplete.query(container, 1)).toBe(getByTestId('autoComplete2'));
 */
export declare function query(container: IContainer, index?: number): QueryReturnElement;
/**
 * Returns input element of AutoComplete
 * @example
 * const { container, getByTestId } = render(
 *     <>
 *         <AutoComplete data-testid="autoComplete1" />
 *         <AutoComplete data-testid="autoComplete2" />
 *     </>
 * );
 * expect(autoComplete.queryInput(container)).toBe(getByTestId('autoComplete1').querySelector('input'));
 * expect(autoComplete.queryInput(container, 1)).toBe(getByTestId('autoComplete2').querySelector('input'));
 */
export declare function queryInput(container: IContainer, index?: number): QueryInputReturnElement;
/**
 * Returns selector element of AutoComplete
 * @example
 * const fn1 = jest.fn();
 * const fn2 = jest.fn();
 * const { container } = render(
 *     <>
 *         <AutoComplete onDropdownVisibleChange={fn1} />
 *         <AutoComplete onDropdownVisibleChange={fn2} />
 *     </>
 * );
 * autoComplete.fireOpen(autoComplete.querySelectorWrapper(container)!);
 * expect(fn1).toBeCalledTimes(1);
 * autoComplete.querySelectorWrapper(container, 1)?.fireOpen();
 * expect(fn2).toBeCalledTimes(1);
 */
export declare function querySelectorWrapper(container: IContainer, index?: number): QuerySelectorWrapperReturnElement;
/**
 * Returns the Select Dropdown which is not hidden
 * @example
 * const fn1 = jest.fn();
 *         const fn2 = jest.fn();
 *         const { container } = render(
 *             <>
 *                 <AutoComplete options={[{ label: '1', value: '1' }]} onSelect={fn1} />
 *                 <AutoComplete options={[{ label: '2', value: '2' }]} onSelect={fn2} />
 *             </>
 *         );
 *         autoComplete.fireOpen(autoComplete.querySelectorWrapper(container)!);
 *         autoComplete.fireSelect(autoComplete.queryDropdown(document)!, 0);
 *         expect(fn1).toBeCalledWith('1', expect.objectContaining({ label: '1', value: '1' }));
 *
 *         autoComplete.querySelectorWrapper(container, 1)?.fireOpen();
 *         autoComplete.queryDropdown(document)?.fireSelect(0);
 *         expect(fn2).toBeCalledWith('2', expect.objectContaining({ label: '2', value: '2' }));
 */
export declare function queryDropdown(container: IContainer): QueryDropdownReturnElement;
/**
 * Returns option element of AutoComplete
 * @example
 * const { container } = render(
 *     <AutoComplete
 *         getPopupContainer={(node) => node.parentNode}
 *         options={[
 *             { label: 'a', value: 'a' },
 *             { label: 'b', value: 'b' },
 *         ]}
 *     />
 * );
 * autoComplete.fireOpen(container);
 * expect(autoComplete.queryOption(container)?.textContent).toBe('a');
 * expect(autoComplete.queryOption(container, 1)?.textContent).toBe('b');
 */
export declare function queryOption(container: IContainer, index?: number): QueryOptionReturnElement;
/**
 * Returns clear icon element of AutoComplete
 * @example
 * const fn1 = jest.fn();
 *         const fn2 = jest.fn();
 *         const { container } = render(
 *             <>
 *                 <AutoComplete onClear={fn1} value={1} allowClear options={[{ label: 'a', value: 'a' }]} />
 *                 <AutoComplete onClear={fn2} value={1} allowClear options={[{ label: 'a', value: 'a' }]} />
 *             </>
 *         );
 *         autoComplete.fireClear(autoComplete.queryClear(container)!);
 *         expect(fn1).toBeCalledTimes(1);
 *         expect(fn2).not.toBeCalled();
 *
 *         autoComplete.queryClear(container, 1)?.fireClear();
 *         expect(fn2).toBeCalledTimes(1);
 */
export declare function queryClear(container: IContainer, index?: number): QueryClearReturnElement;

type QueryReturnElement = MixinElement<{
        query: typeof query;
        queryInput: typeof queryInput;
        querySelectorWrapper: typeof querySelectorWrapper;
        queryDropdown: typeof queryDropdown;
        queryOption: typeof queryOption;
        queryClear: typeof queryClear;
        fireSearch: typeof fireSearch;
        fireOpen: typeof fireOpen;
        fireSelect: typeof fireSelect;
        fireFocus: typeof fireFocus;
        fireBlur: typeof fireBlur;
        fireClear: typeof fireClear;
    }> | null | undefined;
type QueryInputReturnElement = MixinElement<{
        query: typeof select.query;
        queryInput: typeof select.queryInput;
        querySelectorWrapper: typeof select.querySelectorWrapper;
        queryDropdown: typeof select.queryDropdown;
        queryOption: typeof select.queryOption;
        queryClear: typeof select.queryClear;
        fireSearch: typeof select.fireSearch;
        fireOpen: typeof select.fireOpen;
        fireSelect: typeof select.fireSelect;
        fireDeSelect: typeof select.fireDeSelect;
        fireFocus: typeof select.fireFocus;
        fireBlur: typeof select.fireBlur;
        fireClear: typeof select.fireClear;
    }> | null | undefined;
type QuerySelectorWrapperReturnElement = MixinElement<{
        query: typeof select.query;
        queryInput: typeof select.queryInput;
        querySelectorWrapper: typeof select.querySelectorWrapper;
        queryDropdown: typeof select.queryDropdown;
        queryOption: typeof select.queryOption;
        queryClear: typeof select.queryClear;
        fireSearch: typeof select.fireSearch;
        fireOpen: typeof select.fireOpen;
        fireSelect: typeof select.fireSelect;
        fireDeSelect: typeof select.fireDeSelect;
        fireFocus: typeof select.fireFocus;
        fireBlur: typeof select.fireBlur;
        fireClear: typeof select.fireClear;
    }> | null | undefined;
type QueryDropdownReturnElement = MixinElement<{
        query: typeof query;
        queryInput: typeof queryInput;
        querySelectorWrapper: typeof querySelectorWrapper;
        queryDropdown: typeof queryDropdown;
        queryOption: typeof queryOption;
        queryClear: typeof queryClear;
        fireSearch: typeof fireSearch;
        fireOpen: typeof fireOpen;
        fireSelect: typeof fireSelect;
        fireFocus: typeof fireFocus;
        fireBlur: typeof fireBlur;
        fireClear: typeof fireClear;
    }> | null | undefined;
type QueryOptionReturnElement = MixinElement<{
        query: typeof select.query;
        queryInput: typeof select.queryInput;
        querySelectorWrapper: typeof select.querySelectorWrapper;
        queryDropdown: typeof select.queryDropdown;
        queryOption: typeof select.queryOption;
        queryClear: typeof select.queryClear;
        fireSearch: typeof select.fireSearch;
        fireOpen: typeof select.fireOpen;
        fireSelect: typeof select.fireSelect;
        fireDeSelect: typeof select.fireDeSelect;
        fireFocus: typeof select.fireFocus;
        fireBlur: typeof select.fireBlur;
        fireClear: typeof select.fireClear;
    }> | null | undefined;
type QueryClearReturnElement = MixinElement<{
        query: typeof select.query;
        queryInput: typeof select.queryInput;
        querySelectorWrapper: typeof select.querySelectorWrapper;
        queryDropdown: typeof select.queryDropdown;
        queryOption: typeof select.queryOption;
        queryClear: typeof select.queryClear;
        fireSearch: typeof select.fireSearch;
        fireOpen: typeof select.fireOpen;
        fireSelect: typeof select.fireSelect;
        fireDeSelect: typeof select.fireDeSelect;
        fireFocus: typeof select.fireFocus;
        fireBlur: typeof select.fireBlur;
        fireClear: typeof select.fireClear;
    }> | null | undefined;
