import type { IContainer, MixinElement } from '../interface';
/**
 * Fires onChange function.
 *
 * If hexColor and alpha are both provided, `onChange` will trigger twice.
 *
 * Only support `hexColor` format
 * @example
 * const fn = jest.fn();
 * const { container } = render(<ColorPicker onChange={fn} />);
 * colorPicker.fireOpen(container);
 * colorPicker.fireChange(document, { hexColor: '#000000', alpha: '30' });
 * // onChange will triiger twice if change hexColor and alpha at the same time
 * expect(fn.mock.calls[0][1]).toBe('#000000');
 * expect(fn.mock.calls[1][0].metaColor?.a).toBe(0.3);
 */
export declare function fireChange(container: IContainer, color: {
    hexColor?: string;
    alpha?: string;
}): void;
/**
 * Fires `onOpenChange` function
 * @example
 * const { container } = render(<ColorPicker trigger="click" />);
 * colorPicker.fireOpen(container);
 * expect(colorPicker.queryColorPanel(document)).toBeTruthy();
 */
export declare function fireOpen(container: IContainer, index?: number, trigger?: 'click' | 'hover'): void;
/**
 * Returns the `index` container of ColorPicker
 * @param index defualt is `0`
 * @example
 * const { container, getByTestId } = render(
 *     <>
 *         <ColorPicker data-testid="colorPicker1" />
 *         <ColorPicker data-testid="colorPicker2" />
 *     </>
 * );
 * expect(colorPicker.query(container)).toEqual(getByTestId('colorPicker1'));
 * expect(colorPicker.query(container, 1)).toEqual(getByTestId('colorPicker2'));
 */
export declare function query(container: IContainer, index?: number): QueryReturnElement;
/**
 * Returns the popover panel of ColorPicker
 * @example
 * const { container } = render(<ColorPicker />);
 * colorPicker.fireOpen(container);
 * expect(colorPicker.queryColorPanel(document)).toBeTruthy();
 */
export declare function queryColorPanel(container: IContainer): QueryColorPanelReturnElement;
/**
 * Returns the hex color input of ColorPicker
 * @example
 * render(<ColorPicker value="#FFFFFF" open />);
 * expect((colorPicker.queryColorInput(document) as unknown as HTMLInputElement)?.value).toBe('ffffff');
 */
export declare function queryColorInput(container: IContainer): QueryColorInputReturnElement;
/**
 * Returns the alpha input of ColorPicker
 * @example
 * render(<ColorPicker value="#FFFFFF00" open />);
 * expect((colorPicker.queryColorAlphaInput(document) as unknown as HTMLInputElement)?.value).toBe('0%');
 */
export declare function queryColorAlphaInput(container: IContainer): QueryColorAlphaInputReturnElement;

type QueryReturnElement = MixinElement<{
        query: typeof query;
        queryColorPanel: typeof queryColorPanel;
        queryColorInput: typeof queryColorInput;
        queryColorAlphaInput: typeof queryColorAlphaInput;
        fireChange: typeof fireChange;
        fireOpen: typeof fireOpen;
    }> | null | undefined;
type QueryColorPanelReturnElement = MixinElement<{
        query: typeof query;
        queryColorPanel: typeof queryColorPanel;
        queryColorInput: typeof queryColorInput;
        queryColorAlphaInput: typeof queryColorAlphaInput;
        fireChange: typeof fireChange;
        fireOpen: typeof fireOpen;
    }> | null | undefined;
type QueryColorInputReturnElement = MixinElement<{
        query: typeof query;
        queryColorPanel: typeof queryColorPanel;
        queryColorInput: typeof queryColorInput;
        queryColorAlphaInput: typeof queryColorAlphaInput;
        fireChange: typeof fireChange;
        fireOpen: typeof fireOpen;
    }> | null | undefined;
type QueryColorAlphaInputReturnElement = MixinElement<{
        query: typeof query;
        queryColorPanel: typeof queryColorPanel;
        queryColorInput: typeof queryColorInput;
        queryColorAlphaInput: typeof queryColorAlphaInput;
        fireChange: typeof fireChange;
        fireOpen: typeof fireOpen;
    }> | null | undefined;
