import type { IContainer, MixinElement } from '../interface';
/**
 * Fires onClick function of menu item
 * @example
 * const fn = jest.fn();
 *         const menuItems: MenuItems = [
 *             { key: 'Option1', label: 'Option1' },
 *             { key: 'Option2', label: 'Option2' },
 *         ];
 *
 *         const { container } = await act(async () => render(<Menu items={menuItems} onClick={fn} />));
 *         menu.fireMenuItemClick(container, 0);
 *         expect(fn.mock.calls[0][0]).toMatchObject({ key: 'Option1' });
 */
export declare function fireMenuItemClick(container: IContainer, index: number): void;
/**
 * Fires onClick function of sub menu item
 * @example
 * const fn = jest.fn();
 *         const menuItems: MenuItems = [
 *             { key: 'Option1', label: 'Option1' },
 *             {
 *                 key: 'SubOption1',
 *                 label: 'SubOption1',
 *                 children: [{ key: 'Option2', label: 'Option2' }],
 *             },
 *             {
 *                 key: 'SubOption2',
 *                 label: 'SubOption2',
 *                 children: [{ key: 'Option3', label: 'Option3' }],
 *             },
 *         ];
 *
 *         const { container } = await act(async () =>
 *             render(<Menu items={menuItems} onOpenChange={fn} triggerSubMenuAction="click" />)
 *         );
 *         menu.fireSubMenuClick(container, 1);
 *         expect(fn).toBeCalledWith(['SubOption2']);
 */
export declare function fireSubMenuClick(container: IContainer, index: number): void;
/**
 * Returns the `index` container of Menu
 * @param index default is `0`
 * @example
 * const { container, getByTestId } = render(
 *     <>
 *         <Menu data-testid="test1" items={[]} />
 *         <Menu data-testid="test2" items={[]} />
 *     </>
 * );
 * expect(menu.query(container)).toEqual(getByTestId('test1'));
 * expect(menu.query(container, 1)).toEqual(getByTestId('test2'));
 */
export declare function query(container: IContainer, index?: number): QueryReturnElement;

type QueryReturnElement = MixinElement<{
        query: typeof query;
        fireMenuItemClick: typeof fireMenuItemClick;
        fireSubMenuClick: typeof fireSubMenuClick;
    }> | null | undefined;
