import { IContainer, MixinElement } from '../interface';
/**
 * Fires onClick function
 * @example
 * const fn = jest.fn();
 * const { container } = render(
 *     <Button
 *         onClick={() =>
 *             Message.info({
 *                 content: 'this is message',
 *                 onClick: fn,
 *             })
 *         }
 *     >
 *         Display
 *     </Button>
 * );
 * button.fireClick(container);
 * message.fireClick(document);
 * await waitFor(async () => {
 *     expect(fn).toBeCalledTimes(1);
 * });
 */
export declare function fireClick(container: IContainer): void;
/**
 * Fires onClose function by waiting duration
 * @param {number} duration ms
 * @example
 * const fn = jest.fn();
 * const { container } = render(
 *     <Button
 *         onClick={() =>
 *             Message.info({
 *                 content: 'this is message',
 *                 duration: 4,
 *                 onClose: fn,
 *             })
 *         }
 *     >
 *         Display
 *     </Button>
 * );
 * button.fireClick(container);
 * await message.fireClose(4000);
 * await waitFor(async () => {
 *     expect(fn).toBeCalledTimes(1);
 * });
 */
export declare function fireClose(duration?: number): Promise<void>;
/**
 * Returns the container element
 * @example
 * const { container } = render(<Button onClick={() => Message.info('This is message')}>Display</Button>);
 * button.fireClick(container);
 * await waitFor(async () => {
 *     expect(message.query(document)).not.toBeNull();
 * });
 */
export declare function query(container: IContainer, index?: number): QueryReturnElement;
/**
 * Returns the content element
 */
export declare function queryContent(container: IContainer, index?: number): QueryContentReturnElement;

type QueryReturnElement = MixinElement<{
        query: typeof query;
        queryContent: typeof queryContent;
        fireClick: typeof fireClick;
    }> | null | undefined;
type QueryContentReturnElement = MixinElement<{
        query: typeof query;
        queryContent: typeof queryContent;
        fireClick: typeof fireClick;
    }> | null | undefined;
