import * as button from '../button';
import type { IContainer, MixinElement } from '../interface';
/**
 * Fires onOk function
 * @example
 * const fn = jest.fn();
 * const { container } = render(<Modal getContainer={false} open onOk={fn} />);
 * modal.fireOk(container);
 * expect(fn).toBeCalled();
 */
export declare function fireOk(container: IContainer): void;
/**
 * Fires onCancel function
 * @notice Since there are two ways to call onCancel, called via cancel button by default.
 * If you intent to call onCancel by mask clicked, please call fireCancel with queryMask
 * @example
 * const fn = jest.fn();
 * const { container } = render(<Modal getContainer={false} open onCancel={fn} />);
 * modal.fireCancel(container);
 * expect(fn).toBeCalled();
 */
export declare function fireCancel(container: IContainer): void;
/**
 * Returns the `index` container root element of Modal
 */
export declare function query(container: IContainer, index?: number): QueryReturnElement;
/**
 * Returns the `index` footer element
 * @example
 * const { container } = render(<Modal getContainer={false} open />);
 * expect(modal.queryModalFooter(container)).not.toBeNull();
 */
export declare function queryModalFooter(container: IContainer, index?: number): QueryModalFooterReturnElement;
/**
 * Returns the cancel button
 * @example
 * const fn = jest.fn();
 * const { container } = render(<Modal getContainer={false} open onCancel={fn} />);
 * modal.fireCancel(modal.queryCancelButton(container)!);
 * expect(fn).toBeCalled();
 */
export declare function queryCancelButton(container: IContainer, index?: number): QueryCancelButtonReturnElement;
/**
 * Returns the ok button
 * @example
 * const fn = jest.fn();
 * const { container } = render(<Modal getContainer={false} open onOk={fn} />);
 * modal.fireOk(modal.queryOkButton(container)!);
 * expect(fn).toBeCalled();
 */
export declare function queryOkButton(container: IContainer, index?: number): QueryOkButtonReturnElement;
/**
 * Returns the mask element
 * @example
 * const fn = jest.fn();
 * const { container } = render(<Modal getContainer={false} open onCancel={fn} />);
 * modal.fireCancel(modal.queryMask(container)!);
 * expect(fn).toBeCalled();
 */
export declare function queryMask(container: IContainer, index?: number): QueryMaskReturnElement;
export * as confirm from './confirm';

type QueryReturnElement = MixinElement<{
        query: typeof query;
        queryModalFooter: typeof queryModalFooter;
        queryOkButton: typeof queryOkButton;
        queryCancelButton: typeof queryCancelButton;
        queryMask: typeof queryMask;
        fireOk: typeof fireOk;
        fireCancel: typeof fireCancel;
    }> | null | undefined;
type QueryModalFooterReturnElement = MixinElement<{
        query: typeof query;
        queryModalFooter: typeof queryModalFooter;
        queryOkButton: typeof queryOkButton;
        queryCancelButton: typeof queryCancelButton;
        queryMask: typeof queryMask;
        fireOk: typeof fireOk;
        fireCancel: typeof fireCancel;
    }> | null | undefined;
type QueryCancelButtonReturnElement = HTMLButtonElement | MixinElement<{
        query: typeof button.query;
        fireClick: typeof button.fireClick;
    }> | null | undefined;
type QueryOkButtonReturnElement = HTMLButtonElement | MixinElement<{
        query: typeof button.query;
        fireClick: typeof button.fireClick;
    }> | null | undefined;
type QueryMaskReturnElement = MixinElement<{
        query: typeof query;
        queryModalFooter: typeof queryModalFooter;
        queryOkButton: typeof queryOkButton;
        queryCancelButton: typeof queryCancelButton;
        queryMask: typeof queryMask;
        fireOk: typeof fireOk;
        fireCancel: typeof fireCancel;
    }> | null | undefined;
