import type { IContainer, MixinElement } from '../interface';
/**
 * Fires pageSize's dropdown open
 */
export declare function fireSizeOpen(container: IContainer): void;
/**
 * Fires onShowSizeChange function
 * @example
 * const fn = jest.fn();
 * const { container } = render(<Pagination defaultCurrent={6} total={500} onShowSizeChange={fn} />);
 * pagination.fireSizeOpen(container);
 * pagination.fireSizeChange(container, 1);
 * expect(fn).toBeCalledWith(6, 20);
 */
export declare function fireSizeChange(container: IContainer, index: number): void;
/**
 * Fires onChange function
 * @notice there are majority ways to call onChange
 *
 * The sequence of calling onChange is like
 * `[next button] -> [prev button] -> [container self]`
 *
 * _If you intent to call specific button, call fireChange with queryXXX_
 * @example
 * const fn = jest.fn();
 * const { container } = render(<Pagination defaultCurrent={1} total={500} onChange={fn} />);
 * pagination.fireChange(container);
 * expect(fn).toBeCalledWith(2, 10);
 */
export declare function fireChange(container: HTMLInputElement, value: number): void;
/**
 * @example
 * const fn = jest.fn();
 * const { container } = render(<Pagination defaultCurrent={1} total={500} onChange={fn} />);
 * pagination.fireChange(container);
 * expect(fn).toBeCalledWith(2, 10);
 */
export declare function fireChange(Container: IContainer): void;
/**
 * Returns the container
 * @example
 * const { container } = render(<Pagination defaultCurrent={6} total={500} />);
 * expect(pagination.query(container)).not.toBeNull();
 */
export declare function query(container: IContainer, index?: number): QueryReturnElement;
/**
 * Returns the prev button element
 * @example
 * const { container } = render(<Pagination defaultCurrent={6} total={500} />);
 * expect(pagination.queryPrevButton(container)).not.toBeNull();
 */
export declare function queryPrevButton(container: IContainer, index?: number): QueryPrevButtonReturnElement;
/**
 * Returns the next button element
 * @example
 * const { container } = render(<Pagination defaultCurrent={6} total={500} />);
 * expect(pagination.queryNextButton(container)).not.toBeNull();
 */
export declare function queryNextButton(container: IContainer, index?: number): QueryNextButtonReturnElement;
/**
 * Returns the pagination item element
 * @index page number
 * @example
 * const { container } = render(<Pagination defaultCurrent={6} total={500} />);
 * expect(pagination.queryPaginationItem(container, 1)).not.toBeNull();
 */
export declare function queryPaginationItem(container: IContainer, index: number): QueryPaginationItemReturnElement;
/**
 * Returns the jump next element
 * @example
 * const fn = jest.fn();
 * const { container } = render(<Pagination defaultCurrent={1} total={500} onChange={fn} />);
 * pagination.fireChange(pagination.queryJumpNext(container)!);
 * expect(fn).toBeCalledWith(6, 10);
 */
export declare function queryJumpNext(container: IContainer, index?: number): QueryJumpNextReturnElement;
/**
 * Returns the jump prev element
 * @example
 * const fn = jest.fn();
 * const { container } = render(<Pagination defaultCurrent={6} total={500} onChange={fn} />);
 * pagination.fireChange(pagination.queryJumpPrev(container)!);
 * expect(fn).toBeCalledWith(1, 10);
 */
export declare function queryJumpPrev(container: IContainer, index?: number): QueryJumpPrevReturnElement;
/**
 * Returns the quick jump input element
 * @example
 * const fn = jest.fn();
 * const { container } = render(<Pagination defaultCurrent={6} total={500} onChange={fn} showQuickJumper />);
 * pagination.fireChange(pagination.queryQuickJump(container)!, 20);
 * expect(fn).toBeCalledWith(20, 10);
 */
export declare function queryQuickJump(container: IContainer, index?: number): QueryQuickJumpReturnElement;

type QueryReturnElement = MixinElement<{
        query: typeof query;
        queryNextButton: typeof queryNextButton;
        queryPrevButton: typeof queryPrevButton;
        queryPaginationItem: typeof queryPaginationItem;
        queryJumpNext: typeof queryJumpNext;
        queryJumpPrev: typeof queryJumpPrev;
        queryQuickJump: typeof queryQuickJump;
        fireChange: typeof fireChange;
        fireSizeChange: typeof fireSizeChange;
        fireSizeOpen: typeof fireSizeOpen;
    }> | null | undefined;
type QueryPrevButtonReturnElement = MixinElement<{
        query: typeof query;
        queryNextButton: typeof queryNextButton;
        queryPrevButton: typeof queryPrevButton;
        queryPaginationItem: typeof queryPaginationItem;
        queryJumpNext: typeof queryJumpNext;
        queryJumpPrev: typeof queryJumpPrev;
        queryQuickJump: typeof queryQuickJump;
        fireChange: typeof fireChange;
        fireSizeChange: typeof fireSizeChange;
        fireSizeOpen: typeof fireSizeOpen;
    }> | null | undefined;
type QueryNextButtonReturnElement = MixinElement<{
        query: typeof query;
        queryNextButton: typeof queryNextButton;
        queryPrevButton: typeof queryPrevButton;
        queryPaginationItem: typeof queryPaginationItem;
        queryJumpNext: typeof queryJumpNext;
        queryJumpPrev: typeof queryJumpPrev;
        queryQuickJump: typeof queryQuickJump;
        fireChange: typeof fireChange;
        fireSizeChange: typeof fireSizeChange;
        fireSizeOpen: typeof fireSizeOpen;
    }> | null | undefined;
type QueryPaginationItemReturnElement = MixinElement<{
        query: typeof query;
        queryNextButton: typeof queryNextButton;
        queryPrevButton: typeof queryPrevButton;
        queryPaginationItem: typeof queryPaginationItem;
        queryJumpNext: typeof queryJumpNext;
        queryJumpPrev: typeof queryJumpPrev;
        queryQuickJump: typeof queryQuickJump;
        fireChange: typeof fireChange;
        fireSizeChange: typeof fireSizeChange;
        fireSizeOpen: typeof fireSizeOpen;
    }> | null | undefined;
type QueryJumpNextReturnElement = MixinElement<{
        query: typeof query;
        queryNextButton: typeof queryNextButton;
        queryPrevButton: typeof queryPrevButton;
        queryPaginationItem: typeof queryPaginationItem;
        queryJumpNext: typeof queryJumpNext;
        queryJumpPrev: typeof queryJumpPrev;
        queryQuickJump: typeof queryQuickJump;
        fireChange: typeof fireChange;
        fireSizeChange: typeof fireSizeChange;
        fireSizeOpen: typeof fireSizeOpen;
    }> | null | undefined;
type QueryJumpPrevReturnElement = MixinElement<{
        query: typeof query;
        queryNextButton: typeof queryNextButton;
        queryPrevButton: typeof queryPrevButton;
        queryPaginationItem: typeof queryPaginationItem;
        queryJumpNext: typeof queryJumpNext;
        queryJumpPrev: typeof queryJumpPrev;
        queryQuickJump: typeof queryQuickJump;
        fireChange: typeof fireChange;
        fireSizeChange: typeof fireSizeChange;
        fireSizeOpen: typeof fireSizeOpen;
    }> | null | undefined;
type QueryQuickJumpReturnElement = MixinElement<{
        query: typeof query;
        queryNextButton: typeof queryNextButton;
        queryPrevButton: typeof queryPrevButton;
        queryPaginationItem: typeof queryPaginationItem;
        queryJumpNext: typeof queryJumpNext;
        queryJumpPrev: typeof queryJumpPrev;
        queryQuickJump: typeof queryQuickJump;
        fireChange: typeof fireChange;
        fireSizeChange: typeof fireSizeChange;
        fireSizeOpen: typeof fireSizeOpen;
    }> | null | undefined;
