import type { IContainer, MixinElement } from '../interface';
/**
 * Fires rowSelection's onChange function
 * @example
 * const handleSelect = jest.fn();
 * const { container } = render(
 *     <Table
 *         rowKey="id"
 *         dataSource={dataSource}
 *         columns={columns}
 *         rowSelection={{
 *             onChange: handleSelect,
 *         }}
 *     />
 * );
 * table.fireSelect(container, 1);
 * expect(handleSelect.mock.calls[0][0]).toEqual([2]);
 */
export declare function fireSelect(container: IContainer, index: number): void;
/**
 * Fires rowSelection's onSelectAll function
 * @example
 * const handleSelect = jest.fn();
 * const { container } = render(
 *     <Table
 *         rowKey="id"
 *         dataSource={dataSource}
 *         columns={columns}
 *         rowSelection={{
 *             onSelectAll: handleSelect,
 *         }}
 *     />
 * );
 * table.fireSelectAll(container);
 * expect(handleSelect.mock.calls[0][0]).toBeTruthy();
 */
export declare function fireSelectAll(container: IContainer): void;
/**
 * Fires expandable's onExpand function
 * @example
 * const handleExpand = jest.fn();
 * const { container } = render(
 *     <Table
 *         rowKey="id"
 *         dataSource={dataSource}
 *         columns={columns}
 *         expandable={{
 *             expandedRowRender: (record) => <p>{record.name}</p>,
 *             rowExpandable: (record) => record.id !== 2,
 *             onExpand: handleExpand,
 *         }}
 *     />
 * );
 * table.fireExpand(container, 2);
 * expect(handleExpand.mock.calls[0][0]).toBeTruthy();
 * expect(handleExpand.mock.calls[0][1]).toEqual(dataSource[2]);
 */
export declare function fireExpand(container: IContainer, index: number): void;
/**
 * Returns the wrapper element for Table
 * @example
 * const { container } = render(<Table rowKey="id" dataSource={dataSource} columns={columns} />);
 * expect(table.query(container)).not.toBeNull();
 */
export declare function query(container: IContainer, index?: number): QueryReturnElement;
/**
 * Returns the header element for Table
 * @example
 * const { container } = render(<Table rowKey="id" dataSource={dataSource} columns={columns} />);
 * expect(table.queryHeader(container)).not.toBeNull();
 */
export declare function queryHeader(container: IContainer, index?: number): QueryHeaderReturnElement;
/**
 * Returns the body element for Table
 * @example
 * const { container } = render(<Table rowKey="id" dataSource={dataSource} columns={columns} />);
 * expect(table.queryBody(container)).not.toBeNull();
 */
export declare function queryBody(container: IContainer, index?: number): QueryBodyReturnElement;
/**
 * Returns the row element for Table
 * @example
 * const { container } = render(<Table rowKey="id" dataSource={dataSource} columns={columns} />);
 * expect(table.queryRow(container)).not.toBeNull();
 */
export declare function queryRow(container: IContainer, index?: number): QueryRowReturnElement;

type QueryReturnElement = MixinElement<{
        query: typeof query;
        queryHeader: typeof queryHeader;
        queryBody: typeof queryBody;
        queryRow: typeof queryRow;
        fireSelect: typeof fireSelect;
        fireSelectAll: typeof fireSelectAll;
        fireExpand: typeof fireExpand;
    }> | null | undefined;
type QueryHeaderReturnElement = MixinElement<{
        query: typeof query;
        queryHeader: typeof queryHeader;
        queryBody: typeof queryBody;
        queryRow: typeof queryRow;
        fireSelect: typeof fireSelect;
        fireSelectAll: typeof fireSelectAll;
        fireExpand: typeof fireExpand;
    }> | null | undefined;
type QueryBodyReturnElement = MixinElement<{
        query: typeof query;
        queryHeader: typeof queryHeader;
        queryBody: typeof queryBody;
        queryRow: typeof queryRow;
        fireSelect: typeof fireSelect;
        fireSelectAll: typeof fireSelectAll;
        fireExpand: typeof fireExpand;
    }> | null | undefined;
type QueryRowReturnElement = MixinElement<{
        query: typeof query;
        queryHeader: typeof queryHeader;
        queryBody: typeof queryBody;
        queryRow: typeof queryRow;
        fireSelect: typeof fireSelect;
        fireSelectAll: typeof fireSelectAll;
        fireExpand: typeof fireExpand;
    }> | null | undefined;
