import type { IContainer, MixinElement } from '../interface';
/**
 * Fires onTabClick function
 * @param activeKey the key of tab you want click
 * @example
 * const fn = jest.fn();
 * const { container } = render(<Tabs defaultActiveKey="1" items={items} onTabClick={fn} />);
 * tabs.fireClick(container, '1');
 * expect(fn).toBeCalled();
 */
export declare function fireClick(container: IContainer, activeKey: string): void;
/**
 * Fires onChange function
 * @param activeKey the key of tab you want change to
 * @example
 * const fn = jest.fn();
 * const { container } = render(<Tabs defaultActiveKey="1" items={items} onChange={fn} />);
 * tabs.fireChange(container, '2');
 * expect(fn).toBeCalled();
 */
export declare function fireChange(container: IContainer, activeKey: string): void;
/**
 * Fires onEdit function
 * @example
 * const fn = jest.fn();
 *         const { container } = render(<Tabs defaultActiveKey="1" type="editable-card" items={items} onEdit={fn} />);
 *         tabs.fireEdit(container, 'add');
 *         expect(fn).toBeCalledTimes(1);
 *
 *         tabs.fireEdit(container, 'remove', '1');
 *         expect(fn).toBeCalledTimes(2);
 */
export declare function fireEdit(container: IContainer, action: 'add'): void;
/**
 * @example
 * const fn = jest.fn();
 *         const { container } = render(<Tabs defaultActiveKey="1" type="editable-card" items={items} onEdit={fn} />);
 *         tabs.fireEdit(container, 'add');
 *         expect(fn).toBeCalledTimes(1);
 *
 *         tabs.fireEdit(container, 'remove', '1');
 *         expect(fn).toBeCalledTimes(2);
 */
export declare function fireEdit(container: IContainer, action: 'remove', activeKey: string): void;
/**
 * Returns the container element of Tab
 * @param index default is `0`
 * @example
 * const { container } = render(<Tabs defaultActiveKey="1" items={items} />);
 * expect(tabs.query(container)).not.toBeNull();
 */
export declare function query(container: IContainer, index?: number): QueryReturnElement;
/**
 * Returns the title element in Tab
 * @param activeKey the key of tab you want to query
 * @example
 * const { container } = render(<Tabs defaultActiveKey="1" items={items} />);
 * expect(tabs.queryTabTitle(container, '1')?.textContent).toBe('Tab 1');
 */
export declare function queryTabTitle(container: IContainer, activeKey: string): QueryTabTitleReturnElement;
/**
 * Returns the add button element in Tab
 * @param index default is `0`
 * @example
 * const { container } = render(<Tabs type="editable-card" defaultActiveKey="1" items={items} />);
 * expect(tabs.queryAddButton(container)).toBeInstanceOf(HTMLButtonElement);
 */
export declare function queryAddButton(container: IContainer, index?: number): QueryAddButtonReturnElement;
/**
 * Returns the remove button in Tab
 * @param activeKey the key of tab you want to remove
 * @example
 * const { container } = render(<Tabs type="editable-card" defaultActiveKey="1" items={items} />);
 * expect(tabs.queryRemoveButton(container, '1')).toBeInstanceOf(HTMLButtonElement);
 */
export declare function queryRemoveButton(container: IContainer, activeKey: string): QueryRemoveButtonReturnElement;

type QueryReturnElement = MixinElement<{
        query: typeof query;
        queryTabTitle: typeof queryTabTitle;
        queryAddButton: typeof queryAddButton;
        queryRemoveButton: typeof queryRemoveButton;
        fireClick: typeof fireClick;
        fireChange: typeof fireChange;
        fireEdit: typeof fireEdit;
    }> | null | undefined;
type QueryTabTitleReturnElement = MixinElement<{
        query: typeof query;
        queryTabTitle: typeof queryTabTitle;
        queryAddButton: typeof queryAddButton;
        queryRemoveButton: typeof queryRemoveButton;
        fireClick: typeof fireClick;
        fireChange: typeof fireChange;
        fireEdit: typeof fireEdit;
    }> | null | undefined;
type QueryAddButtonReturnElement = MixinElement<{
        query: typeof query;
        queryTabTitle: typeof queryTabTitle;
        queryAddButton: typeof queryAddButton;
        queryRemoveButton: typeof queryRemoveButton;
        fireClick: typeof fireClick;
        fireChange: typeof fireChange;
        fireEdit: typeof fireEdit;
    }> | null | undefined;
type QueryRemoveButtonReturnElement = MixinElement<{
        query: typeof query;
        queryTabTitle: typeof queryTabTitle;
        queryAddButton: typeof queryAddButton;
        queryRemoveButton: typeof queryRemoveButton;
        fireClick: typeof fireClick;
        fireChange: typeof fireChange;
        fireEdit: typeof fireEdit;
    }> | null | undefined;
