import type { IContainer, MixinElement } from '../interface';
/**
 * Fires onChange function
 * @example
 * const fn = jest.fn();
 * const { container } = render(
 *     <Transfer dataSource={dataSource} selectedKeys={['a']} targetKeys={['b', 'c']} onChange={fn} />
 * );
 * transfer.fireChange(container, 'right');
 * expect(fn).lastCalledWith(['a', 'b', 'c'], 'right', ['a']);
 */
export declare function fireChange(container: IContainer, direction: 'left' | 'right'): void;
/**
 * Fires onScroll function
 * @example
 * const fn = jest.fn();
 * const { container } = render(<Transfer listStyle={{ height: 30 }} dataSource={dataSource} onScroll={fn} />);
 * transfer.fireScroll(container);
 * expect(fn).toBeCalled();
 */
export declare function fireScroll(container: IContainer, type?: 'source' | 'target'): void;
/**
 * Fires onSearch function
 * @example
 * const fn = jest.fn();
 * const { container } = render(
 *     <Transfer
 *         dataSource={dataSource}
 *         showSearch
 *         selectedKeys={[]}
 *         targetKeys={[]}
 *         render={(item) => item.title}
 *         onSearch={fn}
 *     />
 * );
 * transfer.fireSearch(container, { searchText: 'a', direction: 'left' });
 * expect(fn).toBeCalledWith('left', 'a');
 * fn.mockReset();
 * transfer.fireSearch(container, { searchText: 'b', direction: 'right' });
 * expect(fn).toBeCalledWith('right', 'b');
 */
export declare function fireSearch(container: IContainer, opts: {
    searchText: string;
    direction: 'left' | 'right';
}): void;
/**
 * Returns the `index` of container transfer
 * @example
 * const { container } = render(<Transfer />);
 * expect(transfer.query(container)).not.toBeNull();
 */
export declare function query(container: IContainer, index?: number): QueryReturnElement;
/**
 * Returns the operation's button element
 * @param index the index of button you want query, default is `0`
 * @example
 * const { container } = render(<Transfer />);
 * expect(transfer.queryOperationButton(container)).not.toBeNull();
 */
export declare function queryOperationButton(container: IContainer, index?: number): QueryOperationButtonReturnElement;

type QueryReturnElement = MixinElement<{
        query: typeof query;
        queryOperationButton: typeof queryOperationButton;
        fireChange: typeof fireChange;
        fireScroll: typeof fireScroll;
        fireSearch: typeof fireSearch;
    }> | null | undefined;
type QueryOperationButtonReturnElement = MixinElement<{
        query: typeof query;
        queryOperationButton: typeof queryOperationButton;
        fireChange: typeof fireChange;
        fireScroll: typeof fireScroll;
        fireSearch: typeof fireSearch;
    }> | null | undefined;
