import type { IContainer, MixinElement } from '../interface';
/**
 * Fires onCheck function
 * @example
 * const fn = jest.fn();
 *         const { container } = render(<Tree checkable onCheck={fn} treeData={treeData} />);
 *
 *         tree.fireCheck(container, 'parent 1');
 *         expect(fn).toBeCalled();
 */
export declare function fireCheck(container: IContainer, title: string): void;
/**
 * Fires onExpand function
 * @example
 * const fn = jest.fn();
 *         const { container } = render(<Tree checkable onExpand={fn} treeData={treeData} />);
 *
 *         tree.fireExpand(container, 'parent 1');
 *         expect(fn).toBeCalled();
 */
export declare function fireExpand(container: IContainer, title: string): void;
/**
 * Fires onRightClick function
 * @example
 * const fn = jest.fn();
 *         const { container } = render(<Tree checkable onRightClick={fn} treeData={treeData} />);
 *
 *         tree.fireRightClick(container, 'parent 1');
 *         expect(fn).toBeCalled();
 */
export declare function fireRightClick(container: IContainer, title: string): void;
/**
 * Fires onSelect function
 * @example
 * const fn = jest.fn();
 *         const { container } = render(<Tree checkable onSelect={fn} treeData={treeData} />);
 *
 *         tree.fireSelect(container, 'parent 1');
 *         expect(fn).toBeCalled();
 */
export declare function fireSelect(container: IContainer, title: string): void;
/**
 * Drag node. fires onDragStart, onDragEnter, onDragOver, onDragLeave, onDrop, onDragEnd function
 * @param sourceNodeTitle the drag source node title
 * @param targetNodeTitle the drag target node title
 * @example
 * const onDragStart = jest.fn();
 * const onDragEnter = jest.fn();
 * const onDragOver = jest.fn();
 * const onDragLeave = jest.fn();
 * const onDrop = jest.fn();
 * const onDragEnd = jest.fn();
 * const { container } = render(
 *     <Tree
 *         treeData={treeData}
 *         defaultExpandAll
 *         draggable
 *         onDrop={onDrop}
 *         onDragStart={onDragStart}
 *         onDragOver={onDragOver}
 *         onDragEnd={onDragEnd}
 *         onDragEnter={onDragEnter}
 *         onDragLeave={onDragLeave}
 *     />
 * );
 * tree.fireDrag(container, 'leaf1', 'leaf2');
 * expect(onDrop).toHaveBeenCalledWith(
 *     expect.objectContaining({
 *         dragNode: expect.objectContaining({ title: 'leaf1' }),
 *         node: expect.objectContaining({ title: 'leaf2' }),
 *     })
 * );
 * expect(onDragStart).toBeCalled();
 * expect(onDragEnter).toBeCalled();
 * expect(onDragOver).toBeCalled();
 * expect(onDragLeave).toBeCalled();
 * expect(onDragEnd).toBeCalled();
 */
export declare function fireDrag(container: IContainer, sourceNodeTitle: string, targetNodeTitle: string): void;
/**
 * Returns the `index` of container Tree
 * @param index default is `0`
 * @example
 * const { container } = render(
 *     <>
 *         <Tree rootClassName="test1" treeData={treeData} />
 *         <Tree rootClassName="test2" treeData={treeData} />
 *     </>
 * );
 * expect(tree.query(container)?.className).toEqual(expect.stringContaining('test1'));
 * expect(tree.query(container, 1)?.className).toEqual(expect.stringContaining('test2'));
 */
export declare function query(container: IContainer, index?: number): QueryReturnElement;

type QueryReturnElement = MixinElement<{
        query: typeof query;
        fireCheck: typeof fireCheck;
        fireExpand: typeof fireExpand;
        fireRightClick: typeof fireRightClick;
        fireSelect: typeof fireSelect;
        fireDrag: typeof fireDrag;
    }> | null | undefined;
