import type { IContainer, MixinElement } from '../interface';
/**
 * Fires onChange function
 *
 * It's a async fire function
 * @prerequisite call `jest.useFakeTimers()`
 * @example
 * const fn = jest.fn();
 * const props: UploadProps = {
 *     beforeUpload: () => false,
 *     onChange: ({ fileList }) => {
 *         fn(fileList?.[0]);
 *     },
 * };
 * const { container } = render(
 *     <Upload {...props}>
 *         <button type="button">upload</button>
 *     </Upload>
 * );
 * upload.fireUpload(container, [{ name: 'foo.png' }]);
 * await waitFor(() => {
 *     expect(fn).toBeCalledWith(expect.objectContaining({ name: 'foo.png' }));
 * });
 */
export declare function fireUpload(container: IContainer, files: File[] | {
    name: string;
}[]): void;
/**
 * Fires onRemove function
 * @param index default remove item is `0`
 * @example
 * const fn = jest.fn();
 *         const files = [
 *             {
 *                 uid: '-1',
 *                 name: 'foo.png',
 *                 status: 'done',
 *                 url: 'http://www.baidu.com/xxx.png',
 *             },
 *             {
 *                 uid: '-2',
 *                 name: 'bar.png',
 *                 status: 'done',
 *                 url: 'http://www.baidu.com/xxx.png',
 *             },
 *         ];
 *         const props: UploadProps = {
 *             beforeUpload: () => false,
 *             fileList: files as UploadProps['fileList'],
 *             onRemove: fn,
 *         };
 *         const { container } = render(
 *             <Upload {...props}>
 *                 <button type="button">upload</button>
 *             </Upload>
 *         );
 *
 *         upload.fireRemove(container, 1);
 *         await waitFor(() => {
 *             expect(fn.mock.calls[0][0]).toMatchObject({ name: 'bar.png' });
 *         });
 */
export declare function fireRemove(container: IContainer, index?: number): void;
/**
 * Returns the `index` container of Upload
 * @param index default is `0`
 * @example
 * const { container, getByTestId } = render(
 *             <>
 *                 <Upload data-testid="test1">button1</Upload>
 *                 <Upload data-testid="test2">button2</Upload>
 *             </>
 *         );
 *
 *         expect(upload.query(container)).toEqual(getByTestId('test1'));
 *         expect(upload.query(container, 1)).toEqual(getByTestId('test2'));
 */
export declare function query(container: IContainer, index?: number): QueryReturnElement;
/**
 * Returns the `index` container of file list in Upload you already uploaded
 * @param index default is `0`
 * @example
 * const files = [
 *     {
 *         uid: '-1',
 *         name: 'foo.png',
 *         status: 'done',
 *         url: 'http://www.baidu.com/xxx.png',
 *     },
 *     {
 *         uid: '-2',
 *         name: 'bar.png',
 *         status: 'done',
 *         url: 'http://www.baidu.com/xxx.png',
 *     },
 * ];
 * const props: UploadProps = {
 *     beforeUpload: () => false,
 *     fileList: files as UploadProps['fileList'],
 *     itemRender: (_, file) => <div data-testid={file.name}>{file.name}</div>,
 * };
 * const { container, getByTestId } = render(
 *     <Upload {...props}>
 *         <button type="button">upload</button>
 *     </Upload>
 * );
 * expect(upload.queryUploadListItem(container)?.firstElementChild).toEqual(getByTestId('foo.png'));
 * expect(upload.queryUploadListItem(container, 1)?.firstElementChild).toEqual(getByTestId('bar.png'));
 */
export declare function queryUploadListItem(container: IContainer, index?: number): QueryUploadListItemReturnElement;

type QueryReturnElement = MixinElement<{
        query: typeof query;
        queryUploadListItem: typeof queryUploadListItem;
        fireUpload: typeof fireUpload;
        fireRemove: typeof fireRemove;
    }> | null | undefined;
type QueryUploadListItemReturnElement = MixinElement<{
        query: typeof query;
        queryUploadListItem: typeof queryUploadListItem;
        fireUpload: typeof fireUpload;
        fireRemove: typeof fireRemove;
    }> | null | undefined;
